"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _enzyme = require("enzyme");

var _react = _interopRequireDefault(require("react"));

var _SaveButton = require("../SaveButton");

var translate = function translate(label) {
  return label;
};

describe('<SaveButton />', function () {
  it('should render <Button raised={true}/> when raised is true', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SaveButton.SaveButton, {
      raised: true,
      translate: translate
    }));
    var ButtonElement = wrapper.find('Button');
    expect(ButtonElement.length).toEqual(1);
    expect(ButtonElement.at(0).prop('raised')).toEqual(true);
  });
  it('should render <Button raised={false}/> when raised is false', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SaveButton.SaveButton, {
      raised: false,
      translate: translate
    }));
    var ButtonElement = wrapper.find('Button');
    expect(ButtonElement.length).toEqual(1);
    expect(ButtonElement.at(0).prop('raised')).toEqual(false);
  });
  it('should render as submit type when submitOnEnter is true', function () {
    var raisedButtonWrapper = (0, _enzyme.shallow)(_react.default.createElement(_SaveButton.SaveButton, {
      raised: true,
      submitOnEnter: true,
      translate: translate
    }));
    var flatButtonWrapper = (0, _enzyme.shallow)(_react.default.createElement(_SaveButton.SaveButton, {
      raised: false,
      submitOnEnter: true,
      translate: translate
    }));
    expect(raisedButtonWrapper.prop('type')).toEqual('submit');
    expect(flatButtonWrapper.prop('type')).toEqual('submit');
  });
  it('should render as button type when submitOnEnter is false', function () {
    var raisedButtonWrapper = (0, _enzyme.shallow)(_react.default.createElement(_SaveButton.SaveButton, {
      raised: true,
      submitOnEnter: false,
      translate: translate
    }));
    var flatButtonWrapper = (0, _enzyme.shallow)(_react.default.createElement(_SaveButton.SaveButton, {
      raised: false,
      submitOnEnter: false,
      translate: translate
    }));
    expect(raisedButtonWrapper.prop('type')).toEqual('button');
    expect(flatButtonWrapper.prop('type')).toEqual('button');
  });
  it('should trigger submit action when clicked if no saving is in progress', function () {
    var onSubmit = jest.fn();
    var raisedButtonWrapper = (0, _enzyme.shallow)(_react.default.createElement(_SaveButton.SaveButton, {
      raised: true,
      translate: translate,
      handleSubmitWithRedirect: function handleSubmitWithRedirect() {
        return onSubmit;
      },
      saving: false
    }));
    var flatButtonWrapper = (0, _enzyme.shallow)(_react.default.createElement(_SaveButton.SaveButton, {
      raised: false,
      translate: translate,
      handleSubmitWithRedirect: function handleSubmitWithRedirect() {
        return onSubmit;
      },
      saving: false
    }));
    raisedButtonWrapper.simulate('click');
    expect(onSubmit.mock.calls.length).toEqual(1);
    flatButtonWrapper.simulate('click');
    expect(onSubmit.mock.calls.length).toEqual(2);
  });
  it('should not trigger submit action when clicked if saving is in progress', function () {
    var onSubmit = jest.fn();
    var event = {
      preventDefault: jest.fn()
    };
    var raisedButtonWrapper = (0, _enzyme.shallow)(_react.default.createElement(_SaveButton.SaveButton, {
      raised: true,
      translate: translate,
      handleSubmitWithRedirect: function handleSubmitWithRedirect() {
        return onSubmit;
      },
      saving: true
    }));
    var flatButtonWrapper = (0, _enzyme.shallow)(_react.default.createElement(_SaveButton.SaveButton, {
      raised: false,
      translate: translate,
      handleSubmitWithRedirect: function handleSubmitWithRedirect() {
        return onSubmit;
      },
      saving: true
    }));
    raisedButtonWrapper.simulate('click', event);
    expect(event.preventDefault.mock.calls.length).toEqual(1);
    flatButtonWrapper.simulate('click', event);
    expect(event.preventDefault.mock.calls.length).toEqual(2);
    expect(onSubmit.mock.calls.length).toEqual(0);
  });
  it('should show a notification if the form is not valid', function () {
    var onSubmit = jest.fn();
    var showNotification = jest.fn();
    var event = {
      preventDefault: jest.fn()
    };
    var raisedButtonWrapper = (0, _enzyme.shallow)(_react.default.createElement(_SaveButton.SaveButton, {
      raised: true,
      translate: translate,
      handleSubmitWithRedirect: function handleSubmitWithRedirect() {
        return onSubmit;
      },
      invalid: true,
      showNotification: showNotification
    }));
    var flatButtonWrapper = (0, _enzyme.shallow)(_react.default.createElement(_SaveButton.SaveButton, {
      raised: false,
      translate: translate,
      handleSubmitWithRedirect: function handleSubmitWithRedirect() {
        return onSubmit;
      },
      invalid: true,
      showNotification: showNotification
    }));
    raisedButtonWrapper.simulate('click', event);
    expect(showNotification.mock.calls.length).toEqual(1);
    flatButtonWrapper.simulate('click', event);
    expect(showNotification.mock.calls.length).toEqual(2);
    expect(onSubmit.mock.calls.length).toEqual(2);
  });
});