"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _redux = require("redux");

var _reactRedux = require("react-redux");

var _raCore = require("ra-core");

var _ArrayField = require("../ArrayField");

var _NumberField = _interopRequireDefault(require("../NumberField"));

var _TextField = _interopRequireDefault(require("../TextField"));

var _Datagrid = _interopRequireDefault(require("../../list/Datagrid"));

describe('<ArrayField />', function () {
  it('should not fail for empty records', function () {
    var IteratorMock = jest.fn();
    (0, _enzyme.shallow)(_react.default.createElement(_ArrayField.ArrayField, {
      source: "arr",
      record: {}
    }, _react.default.createElement(IteratorMock, null))).dive();
    expect(IteratorMock.mock.calls.length).toBe(1);
    expect(IteratorMock.mock.calls[0][0]).toMatchObject({
      data: {},
      ids: []
    });
  });
  it('should pass the embedded array as data and ids props to child', function () {
    var IteratorMock = jest.fn();
    (0, _enzyme.shallow)(_react.default.createElement(_ArrayField.ArrayField, {
      source: "arr",
      record: {
        arr: [{
          id: 123,
          foo: 'bar'
        }, {
          id: 456,
          foo: 'baz'
        }]
      }
    }, _react.default.createElement(IteratorMock, null))).dive();
    expect(IteratorMock.mock.calls.length).toBe(1);
    expect(IteratorMock.mock.calls[0][0]).toMatchObject({
      data: {
        '{"id":123,"foo":"bar"}': {
          foo: 'bar',
          id: 123
        },
        '{"id":456,"foo":"baz"}': {
          foo: 'baz',
          id: 456
        }
      },
      ids: ['{"id":123,"foo":"bar"}', '{"id":456,"foo":"baz"}']
    });
  });
  it('should render the underlying iterator component', function () {
    var store = (0, _redux.createStore)((0, _redux.combineReducers)({
      i18n: function i18n() {
        return {
          locale: 'en',
          messages: {}
        };
      }
    }));

    var Dummy = function Dummy() {
      return _react.default.createElement(_ArrayField.ArrayField, {
        source: "arr",
        record: {
          arr: [{
            id: 123,
            foo: 'bar'
          }, {
            id: 456,
            foo: 'baz'
          }]
        }
      }, _react.default.createElement(_Datagrid.default, null, _react.default.createElement(_NumberField.default, {
        source: "id"
      }), _react.default.createElement(_TextField.default, {
        source: "foo"
      })));
    };

    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_reactRedux.Provider, {
      store: store
    }, _react.default.createElement(_raCore.TranslationProvider, null, _react.default.createElement(Dummy, null))));
    expect(wrapper.find('DatagridRow TextField span').at(0).text()).toBe('bar');
    expect(wrapper.find('DatagridRow NumberField span').at(0).text()).toBe('123');
    expect(wrapper.find('DatagridRow TextField span').at(1).text()).toBe('baz');
    expect(wrapper.find('DatagridRow NumberField span').at(1).text()).toBe('456');
  });
});