"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _DateField = require("../DateField");

describe('<DateField />', function () {
  it('should return null when the record is not set', function () {
    return _assert.default.equal((0, _enzyme.shallow)(_react.default.createElement(_DateField.DateField, {
      source: "foo"
    })).html(), null);
  });
  it('should return null when the record has no value for the source', function () {
    return _assert.default.equal((0, _enzyme.shallow)(_react.default.createElement(_DateField.DateField, {
      record: {},
      source: "foo"
    })).html(), null);
  });
  it('should render a date', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_DateField.DateField, {
      record: {
        foo: new Date('2017-04-23')
      },
      source: "foo",
      locales: "en-US"
    }));

    _assert.default.equal(wrapper.children().text(), new Date('2017-04-23').toLocaleDateString('en-US'));
  });
  it('should render a date and time when the showtime prop is passed', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_DateField.DateField, {
      record: {
        foo: new Date('2017-04-23 23:05')
      },
      showTime: true,
      source: "foo",
      locales: "en-US"
    }));

    _assert.default.equal(wrapper.children().text(), new Date('2017-04-23 23:05').toLocaleString('en-US'));
  });
  it('should pass the options prop to toLocaleString', function () {
    var date = new Date('2017-04-23');
    var options = {
      weekday: 'long',
      year: 'numeric',
      month: 'long',
      day: 'numeric'
    };
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_DateField.DateField, {
      record: {
        foo: date
      },
      source: "foo",
      locales: "en-US",
      options: options
    }));
    return _assert.default.equal(wrapper.children().text(), date.toLocaleDateString('en-US', options));
  });
  it('should use the locales props as an argument to toLocaleString', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_DateField.DateField, {
      record: {
        foo: new Date('2017-04-23')
      },
      source: "foo",
      locales: "fr-FR"
    }));

    _assert.default.equal(wrapper.children().text(), new Date('2017-04-23').toLocaleDateString('fr-FR'));
  });
  it('should use custom className', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_DateField.DateField, {
      record: {
        foo: new Date('01/01/2016')
      },
      source: "foo",
      locales: "en-US",
      className: "foo"
    }));

    _assert.default.ok(wrapper.is('.foo'));
  });
  it('should handle deep fields', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_DateField.DateField, {
      record: {
        foo: {
          bar: new Date('01/01/2016')
        }
      },
      source: "foo.bar",
      locales: "en-US"
    }));

    _assert.default.equal(wrapper.children().text(), new Date('1/1/2016').toLocaleDateString('en-US'));
  });
});