"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _EmailField = _interopRequireDefault(require("../EmailField"));

describe('<EmailField />', function () {
  it('should render as an email link', function () {
    var record = {
      foo: 'foo@bar.com'
    };
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_EmailField.default, {
      record: record,
      source: "foo"
    }));

    _assert.default.equal(wrapper.find('A').text(), 'foo@bar.com');

    _assert.default.equal(wrapper.find('A').prop('href'), 'mailto:foo@bar.com');
  });
  it('should handle deep fields', function () {
    var record = {
      foo: {
        bar: 'foo@bar.com'
      }
    };
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_EmailField.default, {
      record: record,
      source: "foo.bar"
    }));

    _assert.default.equal(wrapper.text(), 'foo@bar.com');

    _assert.default.equal(wrapper.find('A').prop('href'), 'mailto:foo@bar.com');
  });
  it('should display an email (mailto) link', function () {
    var record = {
      email: 'hal@kubrickcorp.com'
    };
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_EmailField.default, {
      record: record,
      source: "email"
    }));

    _assert.default.equal(wrapper.text(), 'hal@kubrickcorp.com');

    _assert.default.equal(wrapper.find('A').prop('href'), 'mailto:hal@kubrickcorp.com');
  });
  it('should use custom className', function () {
    return _assert.default.deepEqual((0, _enzyme.mount)(_react.default.createElement(_EmailField.default, {
      record: {
        foo: true
      },
      source: "email",
      className: "foo"
    })).prop('className'), 'foo');
  });
});