"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _FileField = require("../FileField");

describe('<FileField />', function () {
  it('should return an empty div when record is not set', function () {
    _assert.default.equal((0, _enzyme.shallow)(_react.default.createElement(_FileField.FileField, {
      source: "url"
    })).html(), '<div></div>');
  });
  it('should render a link with correct attributes based on `source` and `title`', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileField.FileField, {
      record: {
        url: 'http://foo.com/bar.jpg',
        title: 'Hello world!'
      },
      source: "url",
      title: "title"
    }));
    var link = wrapper.find('A');

    _assert.default.equal(link.prop('href'), 'http://foo.com/bar.jpg');

    _assert.default.equal(link.prop('title'), 'Hello world!');
  });
  it('should support deep linking', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileField.FileField, {
      record: {
        file: {
          url: 'http://foo.com/bar.jpg',
          title: 'Hello world!'
        }
      },
      source: "file.url",
      title: "file.title"
    }));
    var link = wrapper.find('A');

    _assert.default.equal(link.prop('href'), 'http://foo.com/bar.jpg');

    _assert.default.equal(link.prop('title'), 'Hello world!');
  });
  it('should allow setting static string as title', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileField.FileField, {
      record: {
        url: 'http://foo.com/bar.jpg'
      },
      source: "url",
      title: "Hello world!"
    }));
    var link = wrapper.find('A');

    _assert.default.equal(link.prop('title'), 'Hello world!');
  });
  it('should allow setting target string', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileField.FileField, {
      record: {
        url: 'http://foo.com/bar.jpg'
      },
      source: "url",
      target: "_blank"
    }));
    var link = wrapper.find('A');

    _assert.default.equal(link.prop('target'), '_blank');
  });
  it('should render a list of links with correct attributes based on `src` and `title`', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileField.FileField, {
      record: {
        files: [{
          url: 'http://foo.com/bar.jpg',
          title: 'Hello world!'
        }, {
          url: 'http://bar.com/foo.jpg',
          title: 'Bye world!'
        }]
      },
      source: "files",
      src: "url",
      title: "title"
    }));
    var links = wrapper.find('A');

    _assert.default.equal(links.at(0).prop('href'), 'http://foo.com/bar.jpg');

    _assert.default.equal(links.at(0).prop('title'), 'Hello world!');

    _assert.default.equal(links.at(1).prop('href'), 'http://bar.com/foo.jpg');

    _assert.default.equal(links.at(1).prop('title'), 'Bye world!');
  });
  it('should use custom className', function () {
    return _assert.default.deepEqual((0, _enzyme.shallow)(_react.default.createElement(_FileField.FileField, {
      record: {
        foo: true
      },
      source: "email",
      className: "foo"
    })).prop('className'), 'foo');
  });
});