"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _ImageField = require("../ImageField");

describe('<ImageField />', function () {
  it('should return an empty div when record is not set', function () {
    _assert.default.equal((0, _enzyme.shallow)(_react.default.createElement(_ImageField.ImageField, {
      source: "url"
    })).html(), '<div></div>');
  });
  it('should render an image with correct attributes based on `source` and `title`', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ImageField.ImageField, {
      record: {
        url: 'http://foo.com/bar.jpg',
        title: 'Hello world!'
      },
      source: "url",
      title: "title"
    }));
    var img = wrapper.find('Img');

    _assert.default.equal(img.prop('src'), 'http://foo.com/bar.jpg');

    _assert.default.equal(img.prop('alt'), 'Hello world!');

    _assert.default.equal(img.prop('title'), 'Hello world!');
  });
  it('should support deep linking', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ImageField.ImageField, {
      record: {
        picture: {
          url: 'http://foo.com/bar.jpg',
          title: 'Hello world!'
        }
      },
      source: "picture.url",
      title: "picture.title"
    }));
    var img = wrapper.find('Img');

    _assert.default.equal(img.prop('src'), 'http://foo.com/bar.jpg');

    _assert.default.equal(img.prop('alt'), 'Hello world!');

    _assert.default.equal(img.prop('title'), 'Hello world!');
  });
  it('should allow setting static string as title', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ImageField.ImageField, {
      record: {
        url: 'http://foo.com/bar.jpg'
      },
      source: "url",
      title: "Hello world!"
    }));
    var img = wrapper.find('Img');

    _assert.default.equal(img.prop('alt'), 'Hello world!');

    _assert.default.equal(img.prop('title'), 'Hello world!');
  });
  it('should render a list of images with correct attributes based on `src` and `title`', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ImageField.ImageField, {
      record: {
        pictures: [{
          url: 'http://foo.com/bar.jpg',
          title: 'Hello world!'
        }, {
          url: 'http://bar.com/foo.jpg',
          title: 'Bye world!'
        }]
      },
      source: "pictures",
      src: "url",
      title: "title"
    }));
    var imgs = wrapper.find('Img');

    _assert.default.equal(imgs.at(0).prop('src'), 'http://foo.com/bar.jpg');

    _assert.default.equal(imgs.at(0).prop('alt'), 'Hello world!');

    _assert.default.equal(imgs.at(0).prop('title'), 'Hello world!');

    _assert.default.equal(imgs.at(1).prop('src'), 'http://bar.com/foo.jpg');

    _assert.default.equal(imgs.at(1).prop('alt'), 'Bye world!');

    _assert.default.equal(imgs.at(1).prop('title'), 'Bye world!');
  });
  it('should use custom className', function () {
    return _assert.default.deepEqual((0, _enzyme.shallow)(_react.default.createElement(_ImageField.ImageField, {
      source: "foo",
      record: {
        foo: true
      },
      className: "foo"
    })).prop('className'), 'foo');
  });
});