"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _NumberField = require("../NumberField");

describe('<NumberField />', function () {
  it('should return null when the record is not set', function () {
    return _assert.default.equal((0, _enzyme.shallow)(_react.default.createElement(_NumberField.NumberField, {
      source: "foo"
    })).html(), null);
  });
  it('should return null when the record has no value for the source', function () {
    return _assert.default.equal((0, _enzyme.shallow)(_react.default.createElement(_NumberField.NumberField, {
      record: {},
      source: "foo"
    })).html(), null);
  });
  it('should render a number', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_NumberField.NumberField, {
      record: {
        foo: 1
      },
      source: "foo"
    }));

    _assert.default.equal(wrapper.children().text(), '1');
  });
  it('should pass the options prop to Intl.NumberFormat', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_NumberField.NumberField, {
      record: {
        foo: 1
      },
      source: "foo",
      locales: "en-US",
      options: {
        minimumFractionDigits: 2
      }
    }));

    _assert.default.equal(wrapper.children().text(), '1.00');
  });
  it('should use custom className', function () {
    return _assert.default.deepEqual((0, _enzyme.shallow)(_react.default.createElement(_NumberField.NumberField, {
      record: {
        foo: true
      },
      source: "foo",
      className: "foo"
    })).prop('className'), 'text-right foo');
  });
  it('should handle deep fields', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_NumberField.NumberField, {
      record: {
        foo: {
          bar: 2
        }
      },
      source: "foo.bar"
    }));

    _assert.default.equal(wrapper.children().text(), '2');
  });
});