"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _ReferenceArrayField = require("../ReferenceArrayField");

var _TextField = _interopRequireDefault(require("../TextField"));

var _SingleFieldList = _interopRequireDefault(require("../../list/SingleFieldList"));

describe('<ReferenceArrayField />', function () {
  it('should render a loading indicator when related records are not yet fetched', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceArrayField.ReferenceArrayFieldView, {
      record: {
        barIds: [1, 2]
      },
      resource: "foo",
      reference: "bar",
      source: "barIds",
      basePath: "",
      data: null,
      ids: [1, 2],
      loadedOnce: false
    }, _react.default.createElement(_SingleFieldList.default, null, _react.default.createElement(_TextField.default, {
      source: "title"
    }))));
    var ProgressElements = wrapper.find('ProgressBar');

    _assert.default.equal(ProgressElements.length, 1);

    var SingleFieldListElement = wrapper.find('SingleFieldList');

    _assert.default.equal(SingleFieldListElement.length, 0);
  });
  it('should render a list of the child component', function () {
    var data = {
      1: {
        id: 1,
        title: 'hello'
      },
      2: {
        id: 2,
        title: 'world'
      }
    };
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceArrayField.ReferenceArrayFieldView, {
      record: {
        barIds: [1, 2]
      },
      resource: "foo",
      reference: "bar",
      source: "barIds",
      basePath: "",
      data: data,
      ids: [1, 2]
    }, _react.default.createElement(_SingleFieldList.default, null, _react.default.createElement(_TextField.default, {
      source: "title"
    }))));
    var ProgressElements = wrapper.find('Progress');

    _assert.default.equal(ProgressElements.length, 0);

    var SingleFieldListElement = wrapper.find('SingleFieldList');

    _assert.default.equal(SingleFieldListElement.length, 1);

    _assert.default.equal(SingleFieldListElement.at(0).prop('resource'), 'bar');

    _assert.default.deepEqual(SingleFieldListElement.at(0).prop('data'), data);

    _assert.default.deepEqual(SingleFieldListElement.at(0).prop('ids'), [1, 2]);
  });
  it('should render nothing when there are no related records', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceArrayField.ReferenceArrayFieldView, {
      record: {
        barIds: [1, 2]
      },
      resource: "foo",
      reference: "bar",
      source: "barIds",
      basePath: "",
      data: {},
      ids: []
    }, _react.default.createElement(_SingleFieldList.default, null, _react.default.createElement(_TextField.default, {
      source: "title"
    }))));
    var ProgressElements = wrapper.find('Progress');

    _assert.default.equal(ProgressElements.length, 0);

    var SingleFieldListElement = wrapper.find('SingleFieldList');

    _assert.default.equal(SingleFieldListElement.length, 1);

    _assert.default.equal(SingleFieldListElement.at(0).prop('resource'), 'bar');

    _assert.default.deepEqual(SingleFieldListElement.at(0).prop('data'), {});

    _assert.default.deepEqual(SingleFieldListElement.at(0).prop('ids'), []);
  });
  it('should support record with string identifier', function () {
    var data = {
      'abc-1': {
        id: 'abc-1',
        title: 'hello'
      },
      'abc-2': {
        id: 'abc-2',
        title: 'world'
      }
    };
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceArrayField.ReferenceArrayFieldView, {
      record: {
        barIds: ['abc-1', 'abc-2']
      },
      resource: "foo",
      reference: "bar",
      source: "barIds",
      basePath: "",
      data: data,
      ids: ['abc-1', 'abc-2']
    }, _react.default.createElement(_SingleFieldList.default, null, _react.default.createElement(_TextField.default, {
      source: "title"
    }))));
    var ProgressElements = wrapper.find('Progress');

    _assert.default.equal(ProgressElements.length, 0);

    var SingleFieldListElement = wrapper.find('SingleFieldList');

    _assert.default.equal(SingleFieldListElement.length, 1);

    _assert.default.equal(SingleFieldListElement.at(0).prop('resource'), 'bar');

    _assert.default.deepEqual(SingleFieldListElement.at(0).prop('data'), data);

    _assert.default.deepEqual(SingleFieldListElement.at(0).prop('ids'), ['abc-1', 'abc-2']);
  });
  it('should support record with number identifier', function () {
    var data = {
      1: {
        id: 1,
        title: 'hello'
      },
      2: {
        id: 2,
        title: 'world'
      }
    };
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceArrayField.ReferenceArrayFieldView, {
      record: {
        barIds: [1, 2]
      },
      resource: "foo",
      reference: "bar",
      source: "barIds",
      basePath: "",
      data: data,
      ids: [1, 2]
    }, _react.default.createElement(_SingleFieldList.default, null, _react.default.createElement(_TextField.default, {
      source: "title"
    }))));
    var ProgressElements = wrapper.find('Progress');

    _assert.default.equal(ProgressElements.length, 0);

    var SingleFieldListElement = wrapper.find('SingleFieldList');

    _assert.default.equal(SingleFieldListElement.length, 1);

    _assert.default.equal(SingleFieldListElement.at(0).prop('resource'), 'bar');

    _assert.default.deepEqual(SingleFieldListElement.at(0).prop('data'), data);

    _assert.default.deepEqual(SingleFieldListElement.at(0).prop('ids'), [1, 2]);
  });
  it('should use custom className', function () {
    var data = {
      1: {
        id: 1,
        title: 'hello'
      },
      2: {
        id: 2,
        title: 'world'
      }
    };
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceArrayField.ReferenceArrayFieldView, {
      record: {
        barIds: [1, 2]
      },
      className: "myClass",
      resource: "foo",
      reference: "bar",
      source: "barIds",
      basePath: "",
      data: data,
      ids: [1, 2]
    }, _react.default.createElement(_SingleFieldList.default, null, _react.default.createElement(_TextField.default, {
      source: "title"
    }))));
    var ProgressElements = wrapper.find('Progress');

    _assert.default.equal(ProgressElements.length, 0);

    var SingleFieldListElement = wrapper.find('SingleFieldList');

    _assert.default.equal(SingleFieldListElement.at(0).prop('className'), 'myClass');
  });
});