"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _ReferenceManyField = require("../ReferenceManyField");

var _TextField = _interopRequireDefault(require("../TextField"));

var _SingleFieldList = _interopRequireDefault(require("../../list/SingleFieldList"));

describe('<ReferenceManyField />', function () {
  it('should render a list of the child component', function () {
    var data = {
      1: {
        id: 1,
        title: 'hello'
      },
      2: {
        id: 2,
        title: 'world'
      }
    };
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceManyField.ReferenceManyFieldView, {
      resource: "foo",
      reference: "bar",
      basePath: "",
      data: data,
      ids: [1, 2]
    }, _react.default.createElement(_SingleFieldList.default, null, _react.default.createElement(_TextField.default, {
      source: "title"
    }))), {
      disableLifecycleMethods: true
    });
    var ProgressElements = wrapper.find('WithStyles(LinearProgress)');

    _assert.default.equal(ProgressElements.length, 0);

    var SingleFieldListElement = wrapper.find('SingleFieldList');

    _assert.default.equal(SingleFieldListElement.length, 1);

    _assert.default.equal(SingleFieldListElement.at(0).prop('resource'), 'bar');

    _assert.default.deepEqual(SingleFieldListElement.at(0).prop('data'), data);

    _assert.default.deepEqual(SingleFieldListElement.at(0).prop('ids'), [1, 2]);
  });
  it('should render nothing when there are no related records', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceManyField.ReferenceManyFieldView, {
      resource: "foo",
      reference: "bar",
      basePath: "",
      data: {},
      ids: []
    }, _react.default.createElement(_SingleFieldList.default, null, _react.default.createElement(_TextField.default, {
      source: "title"
    }))), {
      disableLifecycleMethods: true
    });
    var ProgressElements = wrapper.find('WithStyles(LinearProgress)');

    _assert.default.equal(ProgressElements.length, 0);

    var SingleFieldListElement = wrapper.find('SingleFieldList');

    _assert.default.equal(SingleFieldListElement.length, 1);

    _assert.default.equal(SingleFieldListElement.at(0).prop('resource'), 'bar');

    _assert.default.deepEqual(SingleFieldListElement.at(0).prop('data'), {});

    _assert.default.deepEqual(SingleFieldListElement.at(0).prop('ids'), []);
  });
  it('should support record with string identifier', function () {
    var data = {
      'abc-1': {
        id: 'abc-1',
        title: 'hello'
      },
      'abc-2': {
        id: 'abc-2',
        title: 'world'
      }
    };
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceManyField.ReferenceManyFieldView, {
      resource: "foo",
      reference: "bar",
      basePath: "",
      data: data,
      ids: ['abc-1', 'abc-2']
    }, _react.default.createElement(_SingleFieldList.default, null, _react.default.createElement(_TextField.default, {
      source: "title"
    }))), {
      disableLifecycleMethods: true
    });
    var ProgressElements = wrapper.find('widthStyles(LinearProgress)');

    _assert.default.equal(ProgressElements.length, 0);

    var SingleFieldListElement = wrapper.find('SingleFieldList');

    _assert.default.equal(SingleFieldListElement.length, 1);

    _assert.default.equal(SingleFieldListElement.at(0).prop('resource'), 'bar');

    _assert.default.deepEqual(SingleFieldListElement.at(0).prop('data'), data);

    _assert.default.deepEqual(SingleFieldListElement.at(0).prop('ids'), ['abc-1', 'abc-2']);
  });
  it('should support record with number identifier', function () {
    var data = {
      1: {
        id: 1,
        title: 'hello'
      },
      2: {
        id: 2,
        title: 'world'
      }
    };
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceManyField.ReferenceManyFieldView, {
      resource: "foo",
      reference: "bar",
      basePath: "",
      data: data,
      ids: [1, 2]
    }, _react.default.createElement(_SingleFieldList.default, null, _react.default.createElement(_TextField.default, {
      source: "title"
    }))), {
      disableLifecycleMethods: true
    });
    var ProgressElements = wrapper.find('WithStyles(LinearProgress)');

    _assert.default.equal(ProgressElements.length, 0);

    var SingleFieldListElement = wrapper.find('SingleFieldList');

    _assert.default.equal(SingleFieldListElement.length, 1);

    _assert.default.equal(SingleFieldListElement.at(0).prop('resource'), 'bar');

    _assert.default.deepEqual(SingleFieldListElement.at(0).prop('data'), data);

    _assert.default.deepEqual(SingleFieldListElement.at(0).prop('ids'), [1, 2]);
  });
});