"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _cheerio = require("cheerio");

var _RichTextField = _interopRequireWildcard(require("../RichTextField"));

describe('stripTags', function () {
  it('should strip HTML tags from input', function () {
    _assert.default.equal((0, _RichTextField.removeTags)('<h1>Hello world!</h1>'), 'Hello world!');

    _assert.default.equal((0, _RichTextField.removeTags)('<p>Cake is a lie</p>'), 'Cake is a lie');
  });
  it('should strip HTML tags even with attributes', function () {
    _assert.default.equal((0, _RichTextField.removeTags)('<a href="http://www.zombo.com">Zombo</a>'), 'Zombo');

    _assert.default.equal((0, _RichTextField.removeTags)('<a target="_blank" href="http://www.zombo.com">Zombo</a>'), 'Zombo');
  });
  it('should strip HTML tags splitted on several lines', function () {
    _assert.default.equal((0, _RichTextField.removeTags)("<a\n            href=\"http://www.zombo.com\"\n        >Zombo</a>"), 'Zombo');
  });
  it('should strip HTML embedded tags', function () {
    _assert.default.equal((0, _RichTextField.removeTags)('<marquee><a href="http://www.zombo.com">Zombo</a></marquee>'), 'Zombo');
  });
  it('should strip HTML tags even if they are malformed', function () {
    _assert.default.equal((0, _RichTextField.removeTags)('<p>All our base is belong to us.<p>'), 'All our base is belong to us.');
  });
});
describe('<RichTextField />', function () {
  it('should render as HTML', function () {
    var record = {
      body: '<h1>Hello world!</h1>'
    };
    var wrapper = (0, _enzyme.render)(_react.default.createElement(_RichTextField.default, {
      record: record,
      source: "body"
    }));

    _assert.default.equal((0, _cheerio.html)(wrapper), '<span><span><h1>Hello world!</h1></span></span>');
  });
  it('should handle deep fields', function () {
    var record = {
      foo: {
        body: '<h1>Hello world!</h1>'
      }
    };
    var wrapper = (0, _enzyme.render)(_react.default.createElement(_RichTextField.default, {
      record: record,
      source: "foo.body"
    }));

    _assert.default.equal((0, _cheerio.html)(wrapper), '<span><span><h1>Hello world!</h1></span></span>');
  });
  it('should strip HTML tags if stripTags is set to true', function () {
    var record = {
      body: '<h1>Hello world!</h1>'
    };
    var wrapper = (0, _enzyme.render)(_react.default.createElement(_RichTextField.default, {
      stripTags: true,
      record: record,
      source: "body"
    }));

    _assert.default.equal((0, _cheerio.html)(wrapper), '<span>Hello world!</span>');
  });
  it('should not strip HTML tags if stripTags is set to false', function () {
    var record = {
      body: '<h1>Hello world!</h1>'
    };
    var wrapper = (0, _enzyme.render)(_react.default.createElement(_RichTextField.default, {
      stripTags: false,
      record: record,
      source: "body"
    }));

    _assert.default.equal((0, _cheerio.html)(wrapper), '<span><span><h1>Hello world!</h1></span></span>');
  });
  it('should use custom className', function () {
    return _assert.default.deepEqual((0, _enzyme.shallow)(_react.default.createElement(_RichTextField.default, {
      record: {
        foo: true
      },
      source: "body",
      className: "foo"
    })).prop('className'), 'foo');
  });
});