"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _react = _interopRequireDefault(require("react"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _SelectField = require("../SelectField");

describe('<SelectField />', function () {
  var defaultProps = {
    source: 'foo',
    choices: [{
      id: 0,
      name: 'hello'
    }, {
      id: 1,
      name: 'world'
    }],
    translate: function translate(x) {
      return x;
    }
  };
  it('should return null when the record is not set', function () {
    return _assert.default.equal((0, _enzyme.shallow)(_react.default.createElement(_SelectField.SelectField, defaultProps)).html(), null);
  });
  it('should return null when the record has no value for the source', function () {
    return _assert.default.equal((0, _enzyme.shallow)(_react.default.createElement(_SelectField.SelectField, (0, _extends2.default)({}, defaultProps, {
      record: {}
    }))).html(), null);
  });
  it('should return null when the record has a value for the source not in the choices', function () {
    return _assert.default.equal((0, _enzyme.shallow)(_react.default.createElement(_SelectField.SelectField, (0, _extends2.default)({}, defaultProps, {
      record: {
        foo: 2
      }
    }))).html(), null);
  });
  it('should render the choice', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectField.SelectField, (0, _extends2.default)({}, defaultProps, {
      record: {
        foo: 0
      }
    })));
    var chipElement = wrapper.find('WithStyles(Typography)');

    _assert.default.equal(chipElement.children().text(), 'hello');
  });
  it('should use custom className', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectField.SelectField, (0, _extends2.default)({}, defaultProps, {
      record: {
        foo: 1
      },
      elStyle: {
        margin: 1
      },
      className: "foo"
    })));
    var chipElement = wrapper.find('WithStyles(Typography)');

    _assert.default.deepEqual(chipElement.prop('className'), 'foo');
  });
  it('should handle deep fields', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectField.SelectField, (0, _extends2.default)({}, defaultProps, {
      record: {
        foo: {
          bar: 0
        }
      },
      source: "foo.bar"
    })));
    var chipElement = wrapper.find('WithStyles(Typography)');

    _assert.default.equal(chipElement.children().text(), 'hello');
  });
  it('should use optionValue as value identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectField.SelectField, (0, _extends2.default)({}, defaultProps, {
      record: {
        foo: 0
      },
      optionValue: "foobar",
      choices: [{
        foobar: 0,
        name: 'hello'
      }]
    })));
    var chipElement = wrapper.find('WithStyles(Typography)');

    _assert.default.equal(chipElement.children().text(), 'hello');
  });
  it('should use optionText with a string value as text identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectField.SelectField, (0, _extends2.default)({}, defaultProps, {
      record: {
        foo: 0
      },
      optionText: "foobar",
      choices: [{
        id: 0,
        foobar: 'hello'
      }]
    })));
    var chipElement = wrapper.find('WithStyles(Typography)');

    _assert.default.equal(chipElement.children().text(), 'hello');
  });
  it('should use optionText with a function value as text identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectField.SelectField, (0, _extends2.default)({}, defaultProps, {
      record: {
        foo: 0
      },
      optionText: function optionText(choice) {
        return choice.foobar;
      },
      choices: [{
        id: 0,
        foobar: 'hello'
      }]
    })));
    var chipElement = wrapper.find('WithStyles(Typography)');

    _assert.default.equal(chipElement.children().text(), 'hello');
  });
  it('should use optionText with an element value as text identifier', function () {
    var Foobar = function Foobar(_ref) {
      var record = _ref.record;
      return _react.default.createElement("span", null, record.foobar);
    };

    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectField.SelectField, (0, _extends2.default)({}, defaultProps, {
      record: {
        foo: 0
      },
      optionText: _react.default.createElement(Foobar, null),
      choices: [{
        id: 0,
        foobar: 'hello'
      }]
    })));
    var chipElement = wrapper.find('Foobar');

    _assert.default.deepEqual(chipElement.prop('record'), {
      id: 0,
      foobar: 'hello'
    });
  });
  it('should translate the choice by default', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectField.SelectField, (0, _extends2.default)({}, defaultProps, {
      record: {
        foo: 0
      },
      translate: function translate(x) {
        return "**".concat(x, "**");
      }
    })));
    var chipElement = wrapper.find('WithStyles(Typography)');

    _assert.default.equal(chipElement.children().text(), '**hello**');
  });
  it('should not translate the choice if translateChoice is false', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectField.SelectField, (0, _extends2.default)({}, defaultProps, {
      record: {
        foo: 0
      },
      translate: function translate(x) {
        return "**".concat(x, "**");
      },
      translateChoice: false
    })));
    var chipElement = wrapper.find('WithStyles(Typography)');

    _assert.default.equal(chipElement.children().text(), 'hello');
  });
});