"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _react = _interopRequireWildcard(require("react"));

var _TabbedForm = require("../TabbedForm");

var _FormTab = _interopRequireDefault(require("../FormTab"));

var translate = function translate(label) {
  return label;
};

var muiTheme = {
  textField: {
    errorColor: 'red'
  }
};
describe('<TabbedForm />', function () {
  it('should display <Toolbar />', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_TabbedForm.TabbedForm, {
      location: {},
      match: {},
      translate: translate,
      muiTheme: muiTheme,
      tabsWithErrors: []
    }, _react.default.createElement(_FormTab.default, null), _react.default.createElement(_FormTab.default, null)));
    var toolbar = wrapper.find('WithWidth');

    _assert.default.equal(toolbar.length, 1);
  });
  it('should pass submitOnEnter to <Toolbar />', function () {
    var handleSubmit = function handleSubmit() {};

    var wrapper1 = (0, _enzyme.shallow)(_react.default.createElement(_TabbedForm.TabbedForm, {
      location: {},
      match: {},
      translate: translate,
      submitOnEnter: false,
      handleSubmit: handleSubmit,
      muiTheme: muiTheme,
      tabsWithErrors: []
    }));
    var button1 = wrapper1.find('WithWidth');

    _assert.default.equal(button1.prop('submitOnEnter'), false);

    var wrapper2 = (0, _enzyme.shallow)(_react.default.createElement(_TabbedForm.TabbedForm, {
      location: {},
      match: {},
      translate: translate,
      submitOnEnter: true,
      handleSubmit: handleSubmit,
      muiTheme: muiTheme,
      tabsWithErrors: []
    }));
    var button2 = wrapper2.find('WithWidth');

    _assert.default.strictEqual(button2.prop('submitOnEnter'), true);
  });
  it('should set the style of an inactive Tab button with errors', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_TabbedForm.TabbedForm, {
      location: {
        pathname: '/posts/12'
      },
      match: {
        url: '/posts/12'
      },
      translate: translate,
      muiTheme: muiTheme,
      tabsWithErrors: ['tab2'],
      classes: {
        errorTabButton: 'error'
      }
    }, _react.default.createElement(_FormTab.default, {
      label: "tab1"
    }), _react.default.createElement(_FormTab.default, {
      label: "tab2"
    })));
    var tabs = wrapper.find('translate(FormTab)');
    var tab1 = tabs.at(0);
    var tab2 = tabs.at(1);

    _assert.default.equal(tab1.prop('className'), null);

    _assert.default.equal(tab2.prop('className'), 'error');
  });
  it('should not set the style of an active Tab button with errors', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_TabbedForm.TabbedForm, {
      location: {
        pathname: '/posts/12'
      },
      match: {
        url: '/posts/12'
      },
      translate: translate,
      muiTheme: muiTheme,
      tabsWithErrors: ['tab1'],
      classes: {
        errorTabButton: 'error'
      }
    }, _react.default.createElement(_FormTab.default, {
      label: "tab1"
    }), _react.default.createElement(_FormTab.default, {
      label: "tab2"
    })));
    var tabs = wrapper.find('translate(FormTab)');
    var tab1 = tabs.at(0);
    var tab2 = tabs.at(1);

    _assert.default.equal(tab1.prop('className'), null);

    _assert.default.equal(tab2.prop('className'), null);
  });
  describe('findTabsWithErrors', function () {
    it('should find the tabs containing errors', function () {
      var collectErrors = function collectErrors() {
        return {
          field1: 'required',
          field5: 'required'
        };
      };

      var state = {};
      var props = {
        children: [(0, _react.createElement)(_FormTab.default, {
          label: 'tab1'
        }, (0, _react.createElement)('input', {
          source: 'field1'
        }), (0, _react.createElement)('input', {
          source: 'field2'
        })), (0, _react.createElement)(_FormTab.default, {
          label: 'tab2'
        }, (0, _react.createElement)('input', {
          source: 'field3'
        }), (0, _react.createElement)('input', {
          source: 'field4'
        })), (0, _react.createElement)(_FormTab.default, {
          label: 'tab3'
        }, (0, _react.createElement)('input', {
          source: 'field5'
        }), (0, _react.createElement)('input', {
          source: 'field6'
        }))]
      };
      var tabs = (0, _TabbedForm.findTabsWithErrors)(state, props, collectErrors);

      _assert.default.deepEqual(tabs, ['tab1', 'tab3']);
    });
  });
});