"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _reduxForm = require("redux-form");

var _redux = require("redux");

var _reactRedux = require("react-redux");

var _raCore = require("ra-core");

var _ArrayInput = _interopRequireWildcard(require("../ArrayInput"));

var _NumberInput = _interopRequireDefault(require("../NumberInput"));

var _TextInput = _interopRequireDefault(require("../TextInput"));

var _SimpleFormIterator = _interopRequireDefault(require("../../form/SimpleFormIterator"));

var AppMock = function AppMock(_ref) {
  var children = _ref.children;
  return _react.default.createElement(_reactRedux.Provider, {
    store: (0, _redux.createStore)((0, _redux.combineReducers)({
      form: _reduxForm.reducer,
      i18n: function i18n() {
        return {
          locale: 'en',
          messages: {}
        };
      }
    }))
  }, _react.default.createElement(_raCore.TranslationProvider, null, children));
};

describe('<ArrayInput />', function () {
  it('should render a FieldArray', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ArrayInput.ArrayInput, {
      source: "arr",
      record: {}
    }));
    expect(wrapper.find('translate(pure(FieldTitle))').length).toBe(1);
    expect(wrapper.find('FieldArray').length).toBe(1);
  });
  it('should pass an undefined fields to child when initialized with an undefined value', function () {
    var MockChild = function MockChild() {
      return _react.default.createElement("span", null);
    };

    var DummyForm = function DummyForm() {
      return _react.default.createElement("form", null, _react.default.createElement(_ArrayInput.default, {
        source: "foo"
      }, _react.default.createElement(MockChild, null)));
    };

    var DummyFormRF = (0, _reduxForm.reduxForm)({
      form: 'record-form'
    })(DummyForm);
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(AppMock, null, _react.default.createElement(DummyFormRF, null)));
    expect(wrapper.find('MockChild').prop('fields').getAll()).toBeUndefined();
  });
  it('should pass its record props to its child', function () {
    var MockChild = function MockChild() {
      return _react.default.createElement("span", null);
    };

    var DummyForm = function DummyForm() {
      return _react.default.createElement("form", null, _react.default.createElement(_ArrayInput.default, {
        source: "foo",
        record: {
          iAmRecord: true
        }
      }, _react.default.createElement(MockChild, null)));
    };

    var DummyFormRF = (0, _reduxForm.reduxForm)({
      form: 'record-form'
    })(DummyForm);
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(AppMock, null, _react.default.createElement(DummyFormRF, null)));
    expect(wrapper.find(MockChild).props().record).toEqual({
      iAmRecord: true
    });
  });
  it('should pass redux-form fields to child', function () {
    var MockChild = function MockChild() {
      return _react.default.createElement("span", null);
    };

    var DummyForm = function DummyForm() {
      return _react.default.createElement("form", null, _react.default.createElement(_ArrayInput.default, {
        source: "foo"
      }, _react.default.createElement(MockChild, null)));
    };

    var DummyFormRF = (0, _reduxForm.reduxForm)({
      form: 'record-form'
    })(DummyForm);
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(AppMock, null, _react.default.createElement(DummyFormRF, {
      initialValues: {
        foo: [{
          id: 1
        }, {
          id: 2
        }]
      }
    })));
    expect(wrapper.find('MockChild').prop('fields').getAll()).toEqual([{
      id: 1
    }, {
      id: 2
    }]);
  });
  it('should not create any section subform when the value is undefined', function () {
    var DummyForm = function DummyForm() {
      return _react.default.createElement("form", null, _react.default.createElement(_ArrayInput.default, {
        source: "foo"
      }, _react.default.createElement(_SimpleFormIterator.default, null)));
    };

    var DummyFormRF = (0, _reduxForm.reduxForm)({
      form: 'record-form'
    })(DummyForm);
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(AppMock, null, _react.default.createElement(DummyFormRF, null)));
    expect(wrapper.find('section').length).toBe(0);
  });
  it('should create one section subform per value in the array', function () {
    var DummyForm = function DummyForm() {
      return _react.default.createElement("form", null, _react.default.createElement(_ArrayInput.default, {
        source: "foo"
      }, _react.default.createElement(_SimpleFormIterator.default, null)));
    };

    var DummyFormRF = (0, _reduxForm.reduxForm)({
      form: 'record-form'
    })(DummyForm);
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(AppMock, null, _react.default.createElement(DummyFormRF, {
      initialValues: {
        foo: [{}, {}, {}]
      }
    })));
    expect(wrapper.find('section').length).toBe(3);
  });
  it('should clone each input once per value in the array', function () {
    var DummyForm = function DummyForm() {
      return _react.default.createElement("form", null, _react.default.createElement(_ArrayInput.default, {
        source: "arr"
      }, _react.default.createElement(_SimpleFormIterator.default, null, _react.default.createElement(_NumberInput.default, {
        source: "id"
      }), _react.default.createElement(_TextInput.default, {
        source: "foo"
      }))));
    };

    var DummyFormRF = (0, _reduxForm.reduxForm)({
      form: 'record-form'
    })(DummyForm);
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(AppMock, null, _react.default.createElement(DummyFormRF, {
      initialValues: {
        arr: [{
          id: 123,
          foo: 'bar'
        }, {
          id: 456,
          foo: 'baz'
        }]
      }
    })));
    expect(wrapper.find('NumberInput').length).toBe(2);
    expect(wrapper.find('NumberInput').at(0).prop('input').value).toBe(123);
    expect(wrapper.find('NumberInput').at(1).prop('input').value).toBe(456);
    expect(wrapper.find('TextInput').length).toBe(2);
    expect(wrapper.find('TextInput').at(0).prop('input').value).toBe('bar');
    expect(wrapper.find('TextInput').at(1).prop('input').value).toBe('baz');
  });
});