"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _AutocompleteArrayInput = require("../AutocompleteArrayInput");

describe('<AutocompleteArrayInput />', function () {
  var defaultProps = {
    source: 'foo',
    meta: {},
    input: {
      onChange: function onChange() {}
    },
    translate: function translate(x) {
      return x;
    }
  };
  it('should use a react Autosuggest', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteArrayInput.AutocompleteArrayInput, (0, _extends2.default)({}, defaultProps, {
      input: {
        value: [1]
      },
      choices: [{
        id: 1,
        name: 'hello'
      }]
    })));
    var AutoCompleteElement = wrapper.find('Autosuggest');

    _assert.default.equal(AutoCompleteElement.length, 1);
  });
  it('should extract suggestions from choices', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteArrayInput.AutocompleteArrayInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 'M',
        name: 'Male'
      }, {
        id: 'F',
        name: 'Female'
      }]
    })));
    expect(wrapper.state('suggestions')).toEqual([{
      id: 'M',
      name: 'Male'
    }, {
      id: 'F',
      name: 'Female'
    }]);
  });
  var context = {
    translate: function translate() {
      return 'translated';
    },
    locale: 'en'
  };
  var childContextTypes = {
    translate: _propTypes.default.func.isRequired,
    locale: _propTypes.default.string.isRequired
  };
  it('should use optionText with a string value as text identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteArrayInput.AutocompleteArrayInput, (0, _extends2.default)({}, defaultProps, {
      optionText: "foobar"
    })), {
      context: context,
      childContextTypes: childContextTypes
    });
    var menuItem = wrapper.instance().renderSuggestion({
      id: 'M',
      foobar: 'Male'
    }, {
      query: '',
      highlighted: false
    });
    var MenuItem = (0, _enzyme.render)(menuItem);

    _assert.default.equal(MenuItem.text(), 'Male');
  });
  it('should use optionText with a string value including "." as text identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteArrayInput.AutocompleteArrayInput, (0, _extends2.default)({}, defaultProps, {
      optionText: "foobar.name",
      choices: [{
        id: 'M',
        foobar: {
          name: 'Male'
        }
      }],
      alwaysRenderSuggestions: true
    })), {
      context: context,
      childContextTypes: childContextTypes
    });
    var menuItem = wrapper.instance().renderSuggestion({
      id: 'M',
      foobar: {
        name: 'Male'
      }
    }, {
      query: '',
      highlighted: false
    });
    var MenuItem = (0, _enzyme.render)(menuItem);

    _assert.default.equal(MenuItem.text(), 'Male');
  });
  it('should use optionText with a function value as text identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteArrayInput.AutocompleteArrayInput, (0, _extends2.default)({}, defaultProps, {
      optionText: function optionText(choice) {
        return choice.foobar;
      },
      choices: [{
        id: 'M',
        foobar: 'Male'
      }],
      alwaysRenderSuggestions: true
    })), {
      context: context,
      childContextTypes: childContextTypes
    });
    var menuItem = wrapper.instance().renderSuggestion({
      id: 'M',
      foobar: 'Male'
    }, {
      query: '',
      highlighted: false
    });
    var MenuItem = (0, _enzyme.render)(menuItem);

    _assert.default.equal(MenuItem.text(), 'Male');
  });
  it('should translate the choices by default', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteArrayInput.AutocompleteArrayInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 'M',
        name: 'Male'
      }],
      translate: function translate(x) {
        return "**".concat(x, "**");
      },
      alwaysRenderSuggestions: true
    })), {
      context: context,
      childContextTypes: childContextTypes
    });
    var menuItem = wrapper.instance().renderSuggestion({
      id: 'M',
      name: 'Male'
    }, {
      query: '',
      highlighted: false
    });
    var MenuItem = (0, _enzyme.render)(menuItem);

    _assert.default.equal(MenuItem.text(), '**Male**');
  });
  it('should not translate the choices if translateChoice is false', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteArrayInput.AutocompleteArrayInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 'M',
        name: 'Male'
      }],
      translate: function translate(x) {
        return "**".concat(x, "**");
      },
      translateChoice: false,
      alwaysRenderSuggestions: true
    })), {
      context: context,
      childContextTypes: childContextTypes
    });
    var menuItem = wrapper.instance().renderSuggestion({
      id: 'M',
      name: 'Male'
    }, {
      query: '',
      highlighted: false
    });
    var MenuItem = (0, _enzyme.render)(menuItem);

    _assert.default.equal(MenuItem.text(), 'Male');
  });
  describe('Fix issue #1410', function () {
    it('should not fail when value is empty and new choices are applied', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteArrayInput.AutocompleteArrayInput, (0, _extends2.default)({}, defaultProps, {
        input: {
          value: [],
          onChange: function onChange() {}
        },
        choices: [{
          id: 'M',
          name: 'Male'
        }]
      })));
      wrapper.setProps({
        choices: [{
          id: 'M',
          name: 'Male'
        }]
      });
      expect(wrapper.state('searchText')).toBe('');
    });
    it('should allow optionText to be a function', function () {
      var _optionText = jest.fn();

      (0, _enzyme.mount)(_react.default.createElement(_AutocompleteArrayInput.AutocompleteArrayInput, (0, _extends2.default)({}, defaultProps, {
        input: {
          value: ['M'],
          onChange: function onChange() {}
        },
        choices: [{
          id: 'M',
          name: 'Male'
        }],
        optionText: function optionText(v) {
          _optionText(v);

          return v.name;
        }
      })), {
        context: context,
        childContextTypes: childContextTypes
      });
      expect(_optionText).toHaveBeenCalledTimes(1);
      expect(_optionText).toHaveBeenCalledWith({
        id: 'M',
        name: 'Male'
      });
    });
    it('should allow customized rendering of suggesting item', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_AutocompleteArrayInput.AutocompleteArrayInput, (0, _extends2.default)({}, defaultProps, {
        input: {
          value: [1]
        },
        choices: [{
          id: 'M',
          name: 'Male'
        }, {
          id: 'F',
          name: 'Female'
        }],
        alwaysRenderSuggestions: true,
        suggestionComponent: function suggestionComponent(_ref) {
          var suggestion = _ref.suggestion,
              query = _ref.query,
              isHighlighted = _ref.isHighlighted,
              props = (0, _objectWithoutProperties2.default)(_ref, ["suggestion", "query", "isHighlighted"]);
          return _react.default.createElement("div", (0, _extends2.default)({}, props, {
            "data-field": suggestion.name
          }));
        }
      })), {
        context: context,
        childContextTypes: childContextTypes
      });
      expect(wrapper.find('div[data-field]')).toHaveLength(2);
    });
  });
  it('should displayed helperText if prop is present in meta', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteArrayInput.AutocompleteArrayInput, (0, _extends2.default)({}, defaultProps, {
      meta: {
        helperText: 'Can i help you?'
      }
    })));
    var AutoCompleteElement = wrapper.find('Autosuggest').first();

    _assert.default.deepEqual(AutoCompleteElement.prop('inputProps').meta, {
      helperText: 'Can i help you?'
    });
  });
  describe('error message', function () {
    it('should not be displayed if field is pristine', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteArrayInput.AutocompleteArrayInput, (0, _extends2.default)({}, defaultProps, {
        meta: {
          touched: false
        }
      })));
      var AutoCompleteElement = wrapper.find('Autosuggest').first();

      _assert.default.deepEqual(AutoCompleteElement.prop('inputProps').meta, {
        touched: false
      });
    });
    it('should not be displayed if field has been touched but is valid', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteArrayInput.AutocompleteArrayInput, (0, _extends2.default)({}, defaultProps, {
        meta: {
          touched: true,
          error: false
        }
      })));
      var AutoCompleteElement = wrapper.find('Autosuggest').first();

      _assert.default.deepEqual(AutoCompleteElement.prop('inputProps').meta, {
        touched: true,
        error: false
      });
    });
    it('should be displayed if field has been touched and is invalid', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteArrayInput.AutocompleteArrayInput, (0, _extends2.default)({}, defaultProps, {
        meta: {
          touched: true,
          error: 'Required field.'
        }
      })));
      var AutoCompleteElement = wrapper.find('Autosuggest').first();

      _assert.default.deepEqual(AutoCompleteElement.prop('inputProps').meta, {
        touched: true,
        error: 'Required field.'
      });
    });
  });
});