"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _AutocompleteInput = require("../AutocompleteInput");

describe('<AutocompleteInput />', function () {
  var defaultProps = {
    source: 'foo',
    meta: {},
    input: {},
    translate: function translate(x) {
      return x;
    }
  };
  it('should use a react Autosuggest', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
      input: {
        value: 1
      },
      choices: [{
        id: 1,
        name: 'hello'
      }]
    })));
    var AutoCompleteElement = wrapper.find('Autosuggest');

    _assert.default.equal(AutoCompleteElement.length, 1);
  });
  it('should use the input parameter value as the initial state and input searchText', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
      input: {
        value: 2
      },
      choices: [{
        id: 2,
        name: 'foo'
      }]
    })));
    var AutoCompleteElement = wrapper.find('Autosuggest').first();

    _assert.default.equal(AutoCompleteElement.prop('inputProps').value, 'foo');

    _assert.default.equal(wrapper.state('searchText'), 'foo');
  });
  it('should extract suggestions from choices', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 'M',
        name: 'Male'
      }, {
        id: 'F',
        name: 'Female'
      }]
    })));
    expect(wrapper.state('suggestions')).toEqual([{
      id: 'M',
      name: 'Male'
    }, {
      id: 'F',
      name: 'Female'
    }]);
  });
  it('should use optionValue as value identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
      optionValue: "foobar",
      input: {
        value: 'M'
      },
      choices: [{
        foobar: 'M',
        name: 'Male'
      }]
    })));
    var AutoCompleteElement = wrapper.find('Autosuggest').first();

    _assert.default.equal(AutoCompleteElement.prop('inputProps').value, 'Male');
  });
  it('should use optionValue including "." as value identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
      optionValue: "foobar.id",
      input: {
        value: 'M'
      },
      choices: [{
        foobar: {
          id: 'M'
        },
        name: 'Male'
      }]
    })));
    var AutoCompleteElement = wrapper.find('Autosuggest').first();

    _assert.default.equal(AutoCompleteElement.prop('inputProps').value, 'Male');
  });
  var context = {
    translate: function translate() {
      return 'translated';
    },
    locale: 'en'
  };
  var childContextTypes = {
    translate: _propTypes.default.func.isRequired,
    locale: _propTypes.default.string.isRequired
  };
  it('should use optionText with a string value as text identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
      optionText: "foobar"
    })), {
      context: context,
      childContextTypes: childContextTypes
    });
    var menuItem = wrapper.instance().renderSuggestion({
      id: 'M',
      foobar: 'Male'
    }, {
      query: '',
      highlighted: false
    });
    var MenuItem = (0, _enzyme.render)(menuItem);

    _assert.default.equal(MenuItem.text(), 'Male');
  });
  it('should use optionText with a string value including "." as text identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
      optionText: "foobar.name",
      choices: [{
        id: 'M',
        foobar: {
          name: 'Male'
        }
      }],
      alwaysRenderSuggestions: true
    })), {
      context: context,
      childContextTypes: childContextTypes
    });
    var menuItem = wrapper.instance().renderSuggestion({
      id: 'M',
      foobar: {
        name: 'Male'
      }
    }, {
      query: '',
      highlighted: false
    });
    var MenuItem = (0, _enzyme.render)(menuItem);

    _assert.default.equal(MenuItem.text(), 'Male');
  });
  it('should use optionText with a function value as text identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
      optionText: function optionText(choice) {
        return choice.foobar;
      },
      choices: [{
        id: 'M',
        foobar: 'Male'
      }],
      alwaysRenderSuggestions: true
    })), {
      context: context,
      childContextTypes: childContextTypes
    });
    var menuItem = wrapper.instance().renderSuggestion({
      id: 'M',
      foobar: 'Male'
    }, {
      query: '',
      highlighted: false
    });
    var MenuItem = (0, _enzyme.render)(menuItem);

    _assert.default.equal(MenuItem.text(), 'Male');
  });
  it('should translate the choices by default', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 'M',
        name: 'Male'
      }],
      translate: function translate(x) {
        return "**".concat(x, "**");
      },
      alwaysRenderSuggestions: true
    })), {
      context: context,
      childContextTypes: childContextTypes
    });
    var menuItem = wrapper.instance().renderSuggestion({
      id: 'M',
      name: 'Male'
    }, {
      query: '',
      highlighted: false
    });
    var MenuItem = (0, _enzyme.render)(menuItem);

    _assert.default.equal(MenuItem.text(), '**Male**');
  });
  it('should not translate the choices if translateChoice is false', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 'M',
        name: 'Male'
      }],
      translate: function translate(x) {
        return "**".concat(x, "**");
      },
      translateChoice: false,
      alwaysRenderSuggestions: true
    })), {
      context: context,
      childContextTypes: childContextTypes
    });
    var menuItem = wrapper.instance().renderSuggestion({
      id: 'M',
      name: 'Male'
    }, {
      query: '',
      highlighted: false
    });
    var MenuItem = (0, _enzyme.render)(menuItem);

    _assert.default.equal(MenuItem.text(), 'Male');
  });
  it('should respect shouldRenderSuggestions over default if passed in', function () {
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
      input: {
        value: null
      },
      choices: [{
        id: 'M',
        name: 'Male'
      }],
      shouldRenderSuggestions: function shouldRenderSuggestions() {
        return false;
      }
    })), {
      context: context,
      childContextTypes: childContextTypes
    });
    wrapper.find('input').simulate('focus');
    wrapper.find('input').simulate('change', {
      target: {
        value: 'foo'
      }
    });
    expect(wrapper.state('searchText')).toBe('foo');
    expect(wrapper.state('suggestions')).toHaveLength(1);
    expect(wrapper.find('ListItem')).toHaveLength(0);
  });
  describe('Fix issue #1410', function () {
    it('should not fail when value is null and new choices are applied', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
        input: {
          value: null
        },
        choices: [{
          id: 'M',
          name: 'Male'
        }]
      })));
      wrapper.setProps({
        choices: [{
          id: 'M',
          name: 'Male'
        }]
      });
      expect(wrapper.state('searchText')).toBe('');
    });
    it('should allow optionText to be a function', function () {
      var _optionText = jest.fn();

      (0, _enzyme.mount)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
        input: {
          value: 'M'
        },
        choices: [{
          id: 'M',
          name: 'Male'
        }],
        optionText: function optionText(v) {
          _optionText(v);

          return v.name;
        }
      })), {
        context: context,
        childContextTypes: childContextTypes
      });
      expect(_optionText).toHaveBeenCalledTimes(1);
      expect(_optionText).toHaveBeenCalledWith({
        id: 'M',
        name: 'Male'
      });
    });
    it('should not rerender searchtext while having focus and new choices arrive', function () {
      var _optionText2 = jest.fn();

      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
        input: {
          value: 'M'
        },
        meta: {
          active: true
        },
        choices: [{
          id: 'M',
          name: 'Male'
        }],
        optionText: function optionText(v) {
          _optionText2(v);

          return v.name;
        }
      })), {
        context: context,
        childContextTypes: childContextTypes
      });
      wrapper.find('input').simulate('change', {
        target: {
          value: 'foo'
        }
      });
      wrapper.setProps({
        choices: [{
          id: 'M',
          name: 'Male'
        }, {
          id: 'F',
          name: 'Female'
        }]
      });
      expect(wrapper.state('searchText')).toBe('foo');
    });
    it('should allow input value to be cleared when allowEmpty is true and input text is empty', function () {
      var onBlur = jest.fn();
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
        allowEmpty: true,
        input: {
          value: 'M',
          onBlur: onBlur
        },
        choices: [{
          id: 'M',
          name: 'Male'
        }]
      })), {
        context: context,
        childContextTypes: childContextTypes
      });
      wrapper.find('input').simulate('change', {
        target: {
          value: 'foo'
        }
      });
      wrapper.find('input').simulate('blur');
      expect(onBlur).toHaveBeenCalledTimes(1);
      expect(onBlur).toHaveBeenLastCalledWith('M');
      expect(wrapper.state('searchText')).toBe('Male');
      wrapper.find('input').simulate('change', {
        target: {
          value: ''
        }
      });
      wrapper.find('input').simulate('blur');
      expect(wrapper.state('searchText')).toBe('');
      expect(onBlur).toHaveBeenCalledTimes(2);
      expect(onBlur).toHaveBeenLastCalledWith(null);
    });
    it('should revert the searchText when allowEmpty is false', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
        input: {
          value: 'M'
        },
        choices: [{
          id: 'M',
          name: 'Male'
        }]
      })), {
        context: context,
        childContextTypes: childContextTypes
      });
      wrapper.find('input').simulate('change', {
        target: {
          value: 'foo'
        }
      });
      expect(wrapper.state('searchText')).toBe('foo');
      wrapper.find('input').simulate('blur');
      expect(wrapper.state('searchText')).toBe('Male');
    });
    it('should resolve value from input value', function () {
      var onChange = jest.fn();
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
        input: {
          value: '',
          onChange: onChange
        }
      })), {
        context: context,
        childContextTypes: childContextTypes
      });
      wrapper.setProps({
        choices: [{
          id: 'M',
          name: 'Male'
        }]
      });
      wrapper.find('input').simulate('change', {
        target: {
          value: 'male'
        }
      });
      expect(wrapper.state('searchText')).toBe('Male');
      expect(onChange).toHaveBeenCalledTimes(1);
      expect(onChange).toHaveBeenCalledWith('M');
    });
    it('should reset filter when input value changed', function () {
      var setFilter = jest.fn();
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
        input: {
          value: 1
        },
        setFilter: setFilter
      })), {
        context: context,
        childContextTypes: childContextTypes
      });
      wrapper.find('input').simulate('change', {
        target: {
          value: 'de'
        }
      });
      expect(setFilter).toHaveBeenCalledTimes(1);
      expect(setFilter).toHaveBeenCalledWith('de');
      wrapper.setProps({
        input: {
          value: 2
        }
      });
      expect(setFilter).toHaveBeenCalledTimes(2);
      expect(setFilter).toHaveBeenLastCalledWith('');
    });
    it('should allow customized rendering of suggesting item', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
        input: {
          value: 1
        },
        choices: [{
          id: 'M',
          name: 'Male'
        }, {
          id: 'F',
          name: 'Female'
        }],
        alwaysRenderSuggestions: true,
        suggestionComponent: function suggestionComponent(_ref) {
          var suggestion = _ref.suggestion,
              query = _ref.query,
              isHighlighted = _ref.isHighlighted,
              props = (0, _objectWithoutProperties2.default)(_ref, ["suggestion", "query", "isHighlighted"]);
          return _react.default.createElement("div", (0, _extends2.default)({}, props, {
            "data-field": suggestion.name
          }));
        }
      })), {
        context: context,
        childContextTypes: childContextTypes
      });
      expect(wrapper.find('div[data-field]')).toHaveLength(2);
    });
  });
  it('should displayed helperText if prop is present in meta', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
      meta: {
        helperText: 'Can i help you?'
      }
    })));
    var AutoCompleteElement = wrapper.find('Autosuggest').first();

    _assert.default.deepEqual(AutoCompleteElement.prop('inputProps').meta, {
      helperText: 'Can i help you?'
    });
  });
  describe('error message', function () {
    it('should not be displayed if field is pristine', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
        meta: {
          touched: false
        }
      })));
      var AutoCompleteElement = wrapper.find('Autosuggest').first();

      _assert.default.deepEqual(AutoCompleteElement.prop('inputProps').meta, {
        touched: false
      });
    });
    it('should not be displayed if field has been touched but is valid', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
        meta: {
          touched: true,
          error: false
        }
      })));
      var AutoCompleteElement = wrapper.find('Autosuggest').first();

      _assert.default.deepEqual(AutoCompleteElement.prop('inputProps').meta, {
        touched: true,
        error: false
      });
    });
    it('should be displayed if field has been touched and is invalid', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
        meta: {
          touched: true,
          error: 'Required field.'
        }
      })));
      var AutoCompleteElement = wrapper.find('Autosuggest').first();

      _assert.default.deepEqual(AutoCompleteElement.prop('inputProps').meta, {
        touched: true,
        error: 'Required field.'
      });
    });
  });
  it('passes options.suggestionsContainerProps to the suggestions container', function () {
    var onChange = jest.fn();
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_AutocompleteInput.AutocompleteInput, (0, _extends2.default)({}, defaultProps, {
      input: {
        value: null,
        onChange: onChange
      },
      choices: [{
        id: 1,
        name: 'ab'
      }, {
        id: 2,
        name: 'abc'
      }, {
        id: 3,
        name: '123'
      }],
      options: {
        suggestionsContainerProps: {
          disablePortal: true
        }
      }
    })), {
      context: context,
      childContextTypes: childContextTypes
    });
    expect(wrapper.find('Popper').props().disablePortal).toEqual(true);
  });
});