"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _react = _interopRequireDefault(require("react"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _CheckboxGroupInput = require("../CheckboxGroupInput");

describe('<CheckboxGroupInput />', function () {
  var defaultProps = {
    source: 'foo',
    meta: {},
    choices: [{
      id: 1,
      name: 'John doe'
    }],
    input: {
      onChange: function onChange() {},
      value: []
    },
    translate: function translate(x) {
      return x;
    },
    muiTheme: {
      baseTheme: {},
      textField: {},
      prepareStyles: function prepareStyles() {}
    }
  };
  it('should use a mui Checkbox', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_CheckboxGroupInput.CheckboxGroupInput, defaultProps));
    var CheckboxElement = wrapper.find('FormGroup').find('Label');

    _assert.default.equal(CheckboxElement.length, 1);
  });
  it('should use the input parameter value as the initial input value', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_CheckboxGroupInput.CheckboxGroupInput, (0, _extends2.default)({}, defaultProps, {
      input: {
        value: [1],
        onChange: function onChange() {}
      }
    })));
    var CheckboxElement = wrapper.find('FormGroup').find('Label');

    _assert.default.equal(CheckboxElement.prop('check'), true);
  });
  it('should render choices as mui Checkbox components', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_CheckboxGroupInput.CheckboxGroupInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 'ang',
        name: 'Angular'
      }, {
        id: 'rct',
        name: 'React'
      }]
    })));
    var CheckboxElements = wrapper.find('Input');
    var CheckboxLabels = wrapper.find('Label');

    _assert.default.equal(CheckboxElements.length, 2);

    var CheckboxElement1 = CheckboxElements.first();

    _assert.default.equal(CheckboxElement1.prop('value'), 'ang');

    _assert.default.equal(CheckboxLabels.at(0).text(), 'Angular');

    var CheckboxElement2 = CheckboxElements.at(1);

    _assert.default.equal(CheckboxElement2.prop('value'), 'rct');

    _assert.default.equal(CheckboxLabels.at(1).text(), 'React');
  });
  it('should use optionValue as value identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_CheckboxGroupInput.CheckboxGroupInput, (0, _extends2.default)({}, defaultProps, {
      optionValue: "foobar",
      choices: [{
        foobar: 'foo',
        name: 'Bar'
      }]
    })));
    var CheckboxElements = wrapper.find('Input');
    var CheckboxLabel = wrapper.find('Label');
    var CheckboxElement1 = CheckboxElements.first();

    _assert.default.equal(CheckboxElement1.prop('value'), 'foo');

    _assert.default.equal(CheckboxLabel.text(), 'Bar');
  });
  it('should use optionValue including "." as value identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_CheckboxGroupInput.CheckboxGroupInput, (0, _extends2.default)({}, defaultProps, {
      optionValue: "foobar.id",
      choices: [{
        foobar: {
          id: 'foo'
        },
        name: 'Bar'
      }]
    })));
    var CheckboxElements = wrapper.find('Input');
    var CheckboxLabel = wrapper.find('Label');
    var CheckboxElement1 = CheckboxElements.first();

    _assert.default.equal(CheckboxElement1.prop('value'), 'foo');

    _assert.default.equal(CheckboxLabel.text(), 'Bar');
  });
  it('should use optionText with a string value as text identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_CheckboxGroupInput.CheckboxGroupInput, (0, _extends2.default)({}, defaultProps, {
      optionText: "foobar",
      choices: [{
        id: 'foo',
        foobar: 'Bar'
      }]
    })));
    var CheckboxElements = wrapper.find('Input');
    var CheckboxLabel = wrapper.find('Label');
    var CheckboxElement1 = CheckboxElements.first();

    _assert.default.equal(CheckboxElement1.prop('value'), 'foo');

    _assert.default.equal(CheckboxLabel.text(), 'Bar');
  });
  it('should use optionText with a string value including "." as text identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_CheckboxGroupInput.CheckboxGroupInput, (0, _extends2.default)({}, defaultProps, {
      optionText: "foobar.name",
      choices: [{
        id: 'foo',
        foobar: {
          name: 'Bar'
        }
      }]
    })));
    var CheckboxElements = wrapper.find('Input');
    var CheckboxLabel = wrapper.find('Label');
    var CheckboxElement1 = CheckboxElements.first();

    _assert.default.equal(CheckboxElement1.prop('value'), 'foo');

    _assert.default.equal(CheckboxLabel.text(), 'Bar');
  });
  it('should use optionText with a function value as text identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_CheckboxGroupInput.CheckboxGroupInput, (0, _extends2.default)({}, defaultProps, {
      optionText: function optionText(choice) {
        return choice.foobar;
      },
      choices: [{
        id: 'foo',
        foobar: 'Bar'
      }]
    })));
    var CheckboxElements = wrapper.find('Input');
    var CheckboxLabel = wrapper.find('Label');
    var CheckboxElement1 = CheckboxElements.first();

    _assert.default.equal(CheckboxElement1.prop('value'), 'foo');

    _assert.default.equal(CheckboxLabel.text(), 'Bar');
  });
  it('should use optionText with an element value as text identifier', function () {
    var Foobar = function Foobar(_ref) {
      var record = _ref.record;
      return _react.default.createElement("span", null, record.foobar);
    };

    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_CheckboxGroupInput.CheckboxGroupInput, (0, _extends2.default)({}, defaultProps, {
      optionText: _react.default.createElement(Foobar, null),
      choices: [{
        id: 'foo',
        foobar: 'Bar'
      }]
    })));
    var CheckboxElements = wrapper.find('Input');

    _assert.default.equal(CheckboxElements.prop('value'), 'foo');
  });
  it('should translate the choices by default', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_CheckboxGroupInput.CheckboxGroupInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 'M',
        name: 'Male'
      }, {
        id: 'F',
        name: 'Female'
      }],
      translate: function translate(x) {
        return "**".concat(x, "**");
      }
    })));
    var CheckboxLabel = wrapper.find('Label');

    _assert.default.equal(CheckboxLabel.at(0).text(), '**Male**');
  });
  it('should not translate the choices if translateChoice is false', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_CheckboxGroupInput.CheckboxGroupInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 'M',
        name: 'Male'
      }, {
        id: 'F',
        name: 'Female'
      }],
      translate: function translate(x) {
        return "**".concat(x, "**");
      },
      translateChoice: false
    })));
    var CheckboxLabel = wrapper.find('Label');

    _assert.default.equal(CheckboxLabel.at(0).text(), 'Male');
  });
  it('should displayed helperText if prop is present in meta', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_CheckboxGroupInput.CheckboxGroupInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 'M',
        name: 'Male'
      }, {
        id: 'F',
        name: 'Female'
      }],
      translate: function translate(x) {
        return "**".concat(x, "**");
      },
      translateChoice: false,
      meta: {
        helperText: 'Can i help you?'
      }
    })));
    var helperText = wrapper.find('FormFeedback');

    _assert.default.equal(helperText.length, 1);

    _assert.default.equal(helperText.children().text(), 'Can i help you?');
  });
  describe('error message', function () {
    it('should not be displayed if field is pristine', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_CheckboxGroupInput.CheckboxGroupInput, (0, _extends2.default)({}, defaultProps, {
        choices: [{
          id: 'M',
          name: 'Male'
        }, {
          id: 'F',
          name: 'Female'
        }],
        translate: function translate(x) {
          return "**".concat(x, "**");
        },
        translateChoice: false,
        meta: {
          touched: false
        }
      })));
      var helperText = wrapper.find('FormFeedback');

      _assert.default.equal(helperText.length, 0);
    });
    it('should not be displayed if field has been touched but is valid', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_CheckboxGroupInput.CheckboxGroupInput, (0, _extends2.default)({}, defaultProps, {
        choices: [{
          id: 'M',
          name: 'Male'
        }, {
          id: 'F',
          name: 'Female'
        }],
        translate: function translate(x) {
          return "**".concat(x, "**");
        },
        translateChoice: false,
        meta: {
          touched: true,
          error: false
        }
      })));
      var helperText = wrapper.find('FormFeedback');

      _assert.default.equal(helperText.length, 0);
    });
    it('should be displayed if field has been touched and is invalid', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_CheckboxGroupInput.CheckboxGroupInput, (0, _extends2.default)({}, defaultProps, {
        choices: [{
          id: 'M',
          name: 'Male'
        }, {
          id: 'F',
          name: 'Female'
        }],
        translate: function translate(x) {
          return "**".concat(x, "**");
        },
        translateChoice: false,
        meta: {
          touched: true,
          error: 'Required field.'
        }
      })));
      var helperText = wrapper.find('FormFeedback');

      _assert.default.equal(helperText.length, 1);

      _assert.default.equal(helperText.children().text(), 'Required field.');
    });
    it('should display the error and help text if helperText is present', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_CheckboxGroupInput.CheckboxGroupInput, (0, _extends2.default)({}, defaultProps, {
        choices: [{
          id: 'M',
          name: 'Male'
        }, {
          id: 'F',
          name: 'Female'
        }],
        translate: function translate(x) {
          return "**".concat(x, "**");
        },
        translateChoice: false,
        meta: {
          touched: true,
          error: 'Required field.',
          helperText: 'Can i help you?'
        }
      })));
      var helperText = wrapper.find('FormFeedback');

      _assert.default.equal(helperText.length, 2);

      _assert.default.equal(helperText.at(0).children(0).text(), 'Required field.');

      _assert.default.equal(helperText.at(1).children(0).text(), 'Can i help you?');
    });
  });
});