"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _react = _interopRequireDefault(require("react"));

var _DateInput = require("../DateInput");

describe('<DateInput />', function () {
  it('should render a localized <DatePicker />', function () {
    var input = {
      value: null
    };
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_DateInput.DateInput, {
      source: "foo",
      meta: {},
      input: input
    }));
    var datePicker = wrapper.find('Input');

    _assert.default.equal(datePicker.length, 1);

    _assert.default.equal(datePicker.first().prop('type'), 'date');
  });
  it('should call props `input.onChange` method when changed', function () {
    var input = {
      value: null,
      onChange: jest.fn(),
      onBlur: function onBlur() {}
    };
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_DateInput.DateInput, {
      source: "foo",
      input: input,
      meta: {}
    })).shallow().find('Input');
    wrapper.simulate('change', {
      target: {
        value: '2010-01-04'
      }
    });

    _assert.default.equal(input.onChange.mock.calls[0][0].target.value, '2010-01-04');
  });
  describe('error message', function () {
    it('should not be displayed if field is pristine', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_DateInput.DateInput, {
        source: "foo",
        input: {
          value: null
        },
        meta: {
          touched: false
        }
      }));
      var DatePicker = wrapper.find('FormFeedback');

      _assert.default.equal(DatePicker.length, 0);
    });
    it('should not be displayed if field has been touched but is valid', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_DateInput.DateInput, {
        source: "foo",
        input: {
          value: null
        },
        meta: {
          touched: true,
          error: false
        }
      }));
      var DatePicker = wrapper.find('FormFeedback');

      _assert.default.equal(DatePicker.length, 0);
    });
    it('should be displayed if field has been touched and is invalid', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_DateInput.DateInput, {
        source: "foo",
        input: {
          value: null
        },
        meta: {
          touched: true,
          error: 'Required field.'
        }
      }));
      var DatePicker = wrapper.find('FormFeedback').dive();

      _assert.default.equal(DatePicker.text(), 'Required field.');
    });
  });
});