"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _fileApi = require("file-api");

var _ImageField = require("../../field/ImageField");

var _FileInput = require("../FileInput");

describe('<FileInput />', function () {
  beforeAll(function () {
    global.File = _fileApi.File;
    global.FileReader = _fileApi.FileReader;
  });
  afterAll(function () {
    delete global.File;
    delete global.FileReader;
  });
  it('should display a dropzone', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileInput.FileInput, {
      input: {
        value: {
          picture: null
        }
      },
      translate: function translate(x) {
        return x;
      },
      source: "picture"
    }));

    _assert.default.equal(wrapper.find('Dropzone').length, 1);
  });
  it('should correctly update upon drop when allowing a single file', function () {
    var onBlur = jest.fn();
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileInput.FileInput, {
      input: {
        value: {
          src: 'b64_picture'
        },
        onBlur: onBlur
      },
      translate: function translate(x) {
        return x;
      },
      source: "src"
    }));
    wrapper.instance().onDrop([{
      preview: 'new_b64_picture'
    }]);

    _assert.default.deepEqual(onBlur.mock.calls[0][0], {
      preview: 'new_b64_picture'
    });
  });
  it('should correctly update upon removal when allowing a single file', function () {
    var onBlur = jest.fn();
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileInput.FileInput, {
      input: {
        value: {
          src: 'b64_picture'
        },
        onBlur: onBlur
      },
      translate: function translate(x) {
        return x;
      },
      source: "src"
    }));
    wrapper.instance().onRemove({
      src: 'b64_picture'
    })();

    _assert.default.deepEqual(onBlur.mock.calls[0][0], null);
  });
  it('should correctly update upon drop when allowing multiple files', function () {
    var onBlur = jest.fn();
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileInput.FileInput, {
      input: {
        value: [{
          src: 'b64_picture'
        }, {
          src: 'another_b64_picture'
        }],
        onBlur: onBlur
      },
      translate: function translate(x) {
        return x;
      },
      source: "pictures",
      multiple: true
    }));
    wrapper.instance().onDrop([{
      preview: 'new_b64_picture'
    }]);

    _assert.default.deepEqual(onBlur.mock.calls[0][0], [{
      src: 'b64_picture'
    }, {
      src: 'another_b64_picture'
    }, {
      preview: 'new_b64_picture'
    }]);
  });
  it('should correctly update upon removal when allowing multiple files', function () {
    var onBlur = jest.fn();
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileInput.FileInput, {
      input: {
        value: [{
          src: 'b64_picture'
        }, {
          src: 'another_b64_picture'
        }],
        onBlur: onBlur
      },
      translate: function translate(x) {
        return x;
      },
      source: "pictures",
      multiple: true
    }));
    wrapper.instance().onRemove({
      src: 'another_b64_picture'
    })();

    _assert.default.deepEqual(onBlur.mock.calls[0][0], [{
      src: 'b64_picture'
    }]);
  });
  it('should display correct label depending multiple property', function () {
    var test = function test(multiple, expectedLabel) {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileInput.FileInput, {
        multiple: multiple,
        input: {
          value: {
            picture: null
          }
        },
        translate: function translate(x) {
          return x;
        },
        source: "picture"
      }));

      _assert.default.equal(wrapper.find('Dropzone p').text(), expectedLabel);
    };

    test(false, 'ra.input.file.upload_single');
    test(true, 'ra.input.file.upload_several');
  });
  it('should display correct custom label', function () {
    var test = function test(expectedLabel) {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileInput.FileInput, {
        placeholder: expectedLabel,
        input: {
          value: {
            picture: null
          }
        },
        translate: function translate(x) {
          return x;
        },
        source: "picture"
      }));

      _assert.default.ok(wrapper.find('Dropzone').contains(expectedLabel));
    };

    var CustomLabel = function CustomLabel() {
      return _react.default.createElement("div", null, "Custom label");
    };

    test('custom label');
    test(_react.default.createElement("h1", null, "Custom label"));
    test(_react.default.createElement(CustomLabel, null));
  });
  describe('Image Preview', function () {
    it('should display file preview using child as preview component', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileInput.FileInput, {
        input: {
          value: {
            url: 'http://foo.com/bar.jpg',
            title: 'Hello world!'
          }
        },
        translate: function translate(x) {
          return x;
        }
      }, _react.default.createElement(_ImageField.ImageField, {
        source: "url",
        title: "title"
      })));
      var previewImage = wrapper.find('ImageField');

      _assert.default.equal(previewImage.length, 1);

      _assert.default.equal(previewImage.prop('source'), 'url');

      _assert.default.equal(previewImage.prop('title'), 'title');

      _assert.default.deepEqual(previewImage.prop('record'), {
        title: 'Hello world!',
        url: 'http://foo.com/bar.jpg'
      });
    });
    it('should display all files (when several) previews using child as preview component', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileInput.FileInput, {
        input: {
          value: [{
            url: 'http://foo.com/bar.jpg',
            title: 'Hello world!'
          }, {
            url: 'http://foo.com/qux.bmp',
            title: 'A good old Bitmap!'
          }]
        },
        translate: function translate(x) {
          return x;
        }
      }, _react.default.createElement(_ImageField.ImageField, {
        source: "url",
        title: "title"
      })));
      var previewImages = wrapper.find('ImageField');

      _assert.default.equal(previewImages.length, 2);

      _assert.default.equal(previewImages.at(0).prop('source'), 'url');

      _assert.default.equal(previewImages.at(0).prop('title'), 'title');

      _assert.default.deepEqual(previewImages.at(0).prop('record').title, 'Hello world!');

      _assert.default.deepEqual(previewImages.at(0).prop('record').url, 'http://foo.com/bar.jpg');

      _assert.default.equal(previewImages.at(1).prop('source'), 'url');

      _assert.default.equal(previewImages.at(1).prop('title'), 'title');

      _assert.default.deepEqual(previewImages.at(1).prop('record').title, 'A good old Bitmap!');

      _assert.default.deepEqual(previewImages.at(1).prop('record').url, 'http://foo.com/qux.bmp');
    });
    it('should update previews when updating input value', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileInput.FileInput, {
        source: "picture",
        translate: function translate(x) {
          return x;
        },
        input: {
          value: {
            url: 'http://static.acme.com/foo.jpg'
          }
        }
      }, _react.default.createElement(_ImageField.ImageField, {
        source: "url"
      })));
      var previewImage = wrapper.find('ImageField');
      var previewUrl = previewImage.prop('record').url;

      _assert.default.equal(previewUrl, 'http://static.acme.com/foo.jpg');

      wrapper.setProps({
        input: {
          value: {
            url: 'http://static.acme.com/bar.jpg'
          }
        }
      });
      wrapper.update();
      var updatedPreviewImage = wrapper.find('ImageField');
      var updatedPreviewUrl = updatedPreviewImage.prop('record').url;

      _assert.default.equal(updatedPreviewUrl, 'http://static.acme.com/bar.jpg');
    });
    it('should update previews when dropping a file', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileInput.FileInput, {
        source: "picture",
        translate: function translate(x) {
          return x;
        },
        input: {}
      }, _react.default.createElement(_ImageField.ImageField, {
        source: "url"
      })));
      wrapper.setProps({
        input: {
          value: {
            url: 'blob:http://localhost:8080/1234-5678'
          }
        }
      });
      wrapper.update();
      var imagePreview = wrapper.find('ImageField');
      var previewUrl = imagePreview.prop('record').url;

      _assert.default.equal(previewUrl, 'blob:http://localhost:8080/1234-5678');
    });
  });
  it('should allow to remove an image from the input with `FileInputPreview.onRemove`', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileInput.FileInput, {
      source: "picture",
      translate: function translate(x) {
        return x;
      },
      input: {
        onBlur: function onBlur() {},
        value: [{
          url: 'http://static.acme.com/foo.jpg'
        }, {
          url: 'http://static.acme.com/bar.jpg'
        }, {
          url: 'http://static.acme.com/quz.jpg'
        }]
      }
    }, _react.default.createElement(_ImageField.ImageField, {
      source: "url"
    })));
    var inputPreview = wrapper.find('WithStyles(translate(FileInputPreview))');
    inputPreview.at(1).prop('onRemove')();
    wrapper.update();
    var previewImages = wrapper.find('ImageField').map(function (f) {
      return f.prop('record');
    });

    _assert.default.deepEqual(previewImages, [{
      url: 'http://static.acme.com/foo.jpg'
    }, {
      url: 'http://static.acme.com/quz.jpg'
    }]);
  });
});