"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _FileInputPreview = require("../FileInputPreview");

describe('<FileInputPreview />', function () {
  it('should call `onRemove` prop when clicking on remove button', function () {
    var onRemoveSpy = jest.fn();
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileInputPreview.FileInputPreview, {
      onRemove: onRemoveSpy
    }, _react.default.createElement("div", null, "Child")));
    var removeButton = wrapper.find('WithStyles(IconButton)');
    removeButton.simulate('click');

    _assert.default.equal(onRemoveSpy.mock.calls.length, 1);
  });
  it('should render passed children', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileInputPreview.FileInputPreview, {
      onRemove: function onRemove() {
        return true;
      }
    }, _react.default.createElement("div", {
      id: "child"
    }, "Child")));
    var child = wrapper.find('#child');

    _assert.default.equal(child.length, 1);
  });
  it('should clean up generated URLs for preview', function () {
    var file = {
      preview: 'previewUrl'
    };
    var revokeObjectURL = jest.fn();
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileInputPreview.FileInputPreview, {
      onRemove: function onRemove() {
        return true;
      },
      file: file,
      revokeObjectURL: revokeObjectURL
    }, _react.default.createElement("div", {
      id: "child"
    }, "Child")));
    wrapper.unmount();

    _assert.default.equal(revokeObjectURL.mock.calls[0][0], 'previewUrl');
  });
  it('should not try to clean up preview urls if not passed a File object with a preview', function () {
    var file = {};
    var revokeObjectURL = jest.fn();
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FileInputPreview.FileInputPreview, {
      onRemove: function onRemove() {
        return true;
      },
      file: file,
      revokeObjectURL: revokeObjectURL
    }, _react.default.createElement("div", {
      id: "child"
    }, "Child")));
    wrapper.unmount();

    _assert.default.equal(revokeObjectURL.mock.calls.length, 0);
  });
});