"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _react = _interopRequireDefault(require("react"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _NumberInput = require("../NumberInput");

describe('<NumberInput />', function () {
  var defaultProps = {
    source: 'foo',
    meta: {},
    input: {
      onBlur: function onBlur() {},
      onChange: function onChange() {},
      onFocus: function onFocus() {}
    },
    onChange: function onChange() {},
    onBlur: function onBlur() {},
    onFocus: function onFocus() {}
  };
  it('should use a mui TextField', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_NumberInput.NumberInput, (0, _extends2.default)({}, defaultProps, {
      input: {
        value: 12
      }
    })));
    var TextFieldElement = wrapper.find('Input');

    _assert.default.equal(TextFieldElement.length, 1);

    _assert.default.equal(TextFieldElement.prop('value'), 12);

    _assert.default.equal(TextFieldElement.prop('type'), 'number');
  });
  describe('onChange event', function () {
    it('should be customizable via the `onChange` prop', function () {
      var onChange = jest.fn();
      var props = (0, _objectSpread2.default)({}, defaultProps);
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_NumberInput.NumberInput, (0, _extends2.default)({}, props, {
        onChange: onChange
      })));
      wrapper.find('Input').simulate('change', {
        target: {
          value: 3
        }
      });

      _assert.default.equal(onChange.mock.calls[0][0], 3);
    });
    it('should keep calling redux-form original event', function () {
      var onChange = jest.fn();
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_NumberInput.NumberInput, (0, _extends2.default)({}, defaultProps, {
        input: {
          value: 2,
          onChange: onChange
        }
      })));
      wrapper.find('Input').simulate('change', {
        target: {
          value: 3
        }
      });

      _assert.default.equal(onChange.mock.calls[0][0], 3);
    });
    it('should cast value as a numeric one', function () {
      var onChange = jest.fn();
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_NumberInput.NumberInput, (0, _extends2.default)({}, defaultProps, {
        input: {
          value: '2',
          onChange: onChange
        }
      })));
      wrapper.find('Input').simulate('change', {
        target: {
          value: '2'
        }
      });

      _assert.default.equal(onChange.mock.calls[0][0], 2);
    });
  });
  describe('onFocus event', function () {
    it('should be customizable via the `onFocus` prop', function () {
      var onFocus = jest.fn();
      var props = (0, _objectSpread2.default)({}, defaultProps);
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_NumberInput.NumberInput, (0, _extends2.default)({}, props, {
        onFocus: onFocus
      })));
      wrapper.find('Input').simulate('focus', 3);

      _assert.default.equal(onFocus.mock.calls[0][0], 3);
    });
    it('should keep calling redux-form original event', function () {
      var onFocus = jest.fn();
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_NumberInput.NumberInput, (0, _extends2.default)({}, defaultProps, {
        input: {
          value: 2,
          onFocus: onFocus
        }
      })));
      wrapper.find('Input').simulate('focus', {
        target: {
          value: 3
        }
      });

      _assert.default.deepEqual(onFocus.mock.calls[0][0], {
        target: {
          value: 3
        }
      });
    });
  });
  describe('onBlur event', function () {
    it('should be customizable via the `onBlur` prop', function () {
      var onBlur = jest.fn();
      var props = (0, _objectSpread2.default)({}, defaultProps);
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_NumberInput.NumberInput, (0, _extends2.default)({}, props, {
        onBlur: onBlur
      })));
      wrapper.find('Input').simulate('blur', {
        target: {
          value: 3
        }
      });

      _assert.default.equal(onBlur.mock.calls[0][0], 3);
    });
    it('should keep calling redux-form original event', function () {
      var onBlur = jest.fn();
      var props = (0, _objectSpread2.default)({}, defaultProps, {
        input: (0, _objectSpread2.default)({}, defaultProps.input, {
          onBlur: onBlur
        })
      });
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_NumberInput.NumberInput, props));
      wrapper.find('Input').simulate('blur', {
        target: {
          value: 3
        }
      });

      _assert.default.equal(onBlur.mock.calls[0][0], 3);
    });
    it('should cast value as a numeric one', function () {
      var onBlur = jest.fn();
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_NumberInput.NumberInput, (0, _extends2.default)({}, defaultProps, {
        input: {
          value: '2',
          onBlur: onBlur
        }
      })));
      wrapper.find('Input').simulate('blur', {
        target: {
          value: '2'
        }
      });

      _assert.default.equal(onBlur.mock.calls[0][0], 2);
    });
  });
});