"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _react = _interopRequireDefault(require("react"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _RadioButtonGroupInput = require("../RadioButtonGroupInput");

describe('<RadioButtonGroupInput />', function () {
  var defaultProps = {
    source: 'foo',
    meta: {},
    choices: [1, 2],
    input: {
      value: '2'
    },
    translate: function translate(x) {
      return x;
    }
  };
  it('should use a mui RadioGroup', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_RadioButtonGroupInput.RadioButtonGroupInput, (0, _extends2.default)({}, defaultProps, {
      label: "hello"
    })));
    var RadioGroupElement = wrapper.find('FormGroup');

    _assert.default.equal(RadioGroupElement.length, 1);
  });
  it('should use the input parameter value as the initial input value', function () {
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_RadioButtonGroupInput.RadioButtonGroupInput, (0, _extends2.default)({}, defaultProps, {
      input: {
        value: '2'
      }
    })));
    var RadioGroupElement = wrapper.find('Label').at(1);

    _assert.default.equal(RadioGroupElement.prop('checked'), true);
  });
  it('should render choices as mui FormControlLabel components with a Radio control', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_RadioButtonGroupInput.RadioButtonGroupInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 'M',
        name: 'Male'
      }, {
        id: 'F',
        name: 'Female'
      }]
    })));
    var RadioButtonElements = wrapper.find('Input');
    var RadioButtonLabels = wrapper.find('Label');

    _assert.default.equal(RadioButtonElements.length, 2);

    var RadioButtonElement1 = RadioButtonElements.first();

    _assert.default.equal(RadioButtonElement1.prop('value'), 'M');

    _assert.default.equal(RadioButtonLabels.at(0).text(), 'Male');

    var RadioButtonElement2 = RadioButtonElements.at(1);

    _assert.default.equal(RadioButtonElement2.prop('value'), 'F');

    _assert.default.equal(RadioButtonLabels.at(1).text(), 'Female');
  });
  it('should use optionValue as value identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_RadioButtonGroupInput.RadioButtonGroupInput, (0, _extends2.default)({}, defaultProps, {
      optionValue: "foobar",
      choices: [{
        foobar: 'M',
        name: 'Male'
      }]
    })));
    var RadioButtonElements = wrapper.find('Input');
    var RadioButtonLabels = wrapper.find('Label');
    var RadioButtonElement1 = RadioButtonElements.first();

    _assert.default.equal(RadioButtonElement1.prop('value'), 'M');

    _assert.default.equal(RadioButtonLabels.text(), 'Male');
  });
  it('should use optionValue including "." as value identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_RadioButtonGroupInput.RadioButtonGroupInput, (0, _extends2.default)({}, defaultProps, {
      optionValue: "foobar.id",
      choices: [{
        foobar: {
          id: 'M'
        },
        name: 'Male'
      }]
    })));
    var RadioButtonElements = wrapper.find('Input');
    var RadioButtonLabels = wrapper.find('Label');
    var RadioButtonElement1 = RadioButtonElements.first();

    _assert.default.equal(RadioButtonElement1.prop('value'), 'M');

    _assert.default.equal(RadioButtonLabels.text(), 'Male');
  });
  it('should use optionText with a string value as text identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_RadioButtonGroupInput.RadioButtonGroupInput, (0, _extends2.default)({}, defaultProps, {
      optionText: "foobar",
      choices: [{
        id: 'M',
        foobar: 'Male'
      }]
    })));
    var RadioButtonElements = wrapper.find('Input');
    var RadioButtonLabels = wrapper.find('Label');
    var RadioButtonElement1 = RadioButtonElements.first();

    _assert.default.equal(RadioButtonElement1.prop('value'), 'M');

    _assert.default.equal(RadioButtonLabels.text(), 'Male');
  });
  it('should use optionText with a string value including "." as text identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_RadioButtonGroupInput.RadioButtonGroupInput, (0, _extends2.default)({}, defaultProps, {
      optionText: "foobar.name",
      choices: [{
        id: 'M',
        foobar: {
          name: 'Male'
        }
      }]
    })));
    var RadioButtonElements = wrapper.find('Input');
    var RadioButtonLabels = wrapper.find('Label');
    var RadioButtonElement1 = RadioButtonElements.first();

    _assert.default.equal(RadioButtonElement1.prop('value'), 'M');

    _assert.default.equal(RadioButtonLabels.text(), 'Male');
  });
  it('should use optionText with a function value as text identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_RadioButtonGroupInput.RadioButtonGroupInput, (0, _extends2.default)({}, defaultProps, {
      optionText: function optionText(choice) {
        return choice.foobar;
      },
      choices: [{
        id: 'M',
        foobar: 'Male'
      }]
    })));
    var RadioButtonElements = wrapper.find('Input');
    var RadioButtonLabels = wrapper.find('Label');
    var RadioButtonElement1 = RadioButtonElements.first();

    _assert.default.equal(RadioButtonElement1.prop('value'), 'M');

    _assert.default.equal(RadioButtonLabels.text(), 'Male');
  });
  it('should use optionText with an element value as text identifier', function () {
    var Foobar = function Foobar(_ref) {
      var record = _ref.record;
      return _react.default.createElement("span", null, record.foobar);
    };

    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_RadioButtonGroupInput.RadioButtonGroupInput, (0, _extends2.default)({}, defaultProps, {
      optionText: _react.default.createElement(Foobar, null),
      choices: [{
        id: 'M',
        foobar: 'Male'
      }]
    })));
    var RadioButtonElements = wrapper.find('Input');
    var RadioButtonElement1 = RadioButtonElements.first();

    _assert.default.equal(RadioButtonElement1.prop('value'), 'M');

    _assert.default.equal(wrapper.find('Foobar').length, 1);

    _assert.default.equal(wrapper.find('Foobar').prop('record').id, 'M');

    _assert.default.equal(wrapper.find('Foobar').prop('record').foobar, 'Male');
  });
  it('should translate the choices by default', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_RadioButtonGroupInput.RadioButtonGroupInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 'M',
        name: 'Male'
      }, {
        id: 'F',
        name: 'Female'
      }],
      translate: function translate(x) {
        return "**".concat(x, "**");
      }
    })));
    var RadioButtonLabels = wrapper.find('Label');

    _assert.default.equal(RadioButtonLabels.at(0).text(), '**Male**');
  });
  it('should not translate the choices if translateChoice is false', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_RadioButtonGroupInput.RadioButtonGroupInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 'M',
        name: 'Male'
      }, {
        id: 'F',
        name: 'Female'
      }],
      translate: function translate(x) {
        return "**".concat(x, "**");
      },
      translateChoice: false
    })));
    var RadioButtonLabels = wrapper.find('Label');

    _assert.default.equal(RadioButtonLabels.at(0).text(), 'Male');
  });
  it('should displayed helperText if prop is present in meta', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_RadioButtonGroupInput.RadioButtonGroupInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 'M',
        name: 'Male'
      }, {
        id: 'F',
        name: 'Female'
      }],
      translate: function translate(x) {
        return "**".concat(x, "**");
      },
      translateChoice: false,
      meta: {
        helperText: 'Can i help you?'
      }
    })));
    var helperText = wrapper.find('FormFeedback');

    _assert.default.equal(helperText.length, 1);

    _assert.default.equal(helperText.children().text(), 'Can i help you?');
  });
  describe('error message', function () {
    it('should not be displayed if field is pristine', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_RadioButtonGroupInput.RadioButtonGroupInput, (0, _extends2.default)({}, defaultProps, {
        choices: [{
          id: 'M',
          name: 'Male'
        }, {
          id: 'F',
          name: 'Female'
        }],
        translate: function translate(x) {
          return "**".concat(x, "**");
        },
        translateChoice: false,
        meta: {
          touched: false
        }
      })));
      var helperText = wrapper.find('FormFeedback');

      _assert.default.equal(helperText.length, 0);
    });
    it('should not be displayed if field has been touched but is valid', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_RadioButtonGroupInput.RadioButtonGroupInput, (0, _extends2.default)({}, defaultProps, {
        choices: [{
          id: 'M',
          name: 'Male'
        }, {
          id: 'F',
          name: 'Female'
        }],
        translate: function translate(x) {
          return "**".concat(x, "**");
        },
        translateChoice: false,
        meta: {
          touched: true,
          error: false
        }
      })));
      var helperText = wrapper.find('FormFeedback');

      _assert.default.equal(helperText.length, 0);
    });
    it('should be displayed if field has been touched and is invalid', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_RadioButtonGroupInput.RadioButtonGroupInput, (0, _extends2.default)({}, defaultProps, {
        choices: [{
          id: 'M',
          name: 'Male'
        }, {
          id: 'F',
          name: 'Female'
        }],
        translate: function translate(x) {
          return "**".concat(x, "**");
        },
        translateChoice: false,
        meta: {
          touched: true,
          error: 'Required field.'
        }
      })));
      var helperText = wrapper.find('FormFeedback');

      _assert.default.equal(helperText.length, 1);

      _assert.default.equal(helperText.children().text(), 'Required field.');
    });
    it('should display the error and help text if helperText is present', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_RadioButtonGroupInput.RadioButtonGroupInput, (0, _extends2.default)({}, defaultProps, {
        choices: [{
          id: 'M',
          name: 'Male'
        }, {
          id: 'F',
          name: 'Female'
        }],
        translate: function translate(x) {
          return "**".concat(x, "**");
        },
        translateChoice: false,
        meta: {
          touched: true,
          error: 'Required field.',
          helperText: 'Can i help you?'
        }
      })));
      var helperText = wrapper.find('FormFeedback');

      _assert.default.equal(helperText.length, 2);

      _assert.default.equal(helperText.at(0).children(0).text(), 'Required field.');

      _assert.default.equal(helperText.at(1).children(0).text(), 'Can i help you?');
    });
  });
});