"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _react = _interopRequireDefault(require("react"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _ReferenceArrayInput = require("../ReferenceArrayInput");

describe('<ReferenceArrayInput />', function () {
  var defaultProps = {
    input: {},
    meta: {},
    record: {},
    reference: 'tags',
    resource: 'posts',
    source: 'tag_ids',
    translate: function translate(x) {
      return "*".concat(x, "*");
    }
  };

  var MyComponent = function MyComponent() {
    return _react.default.createElement("span", {
      id: "mycomponent"
    });
  };

  it('should render a LinearProgress if isLoading is true', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceArrayInput.ReferenceArrayInputView, (0, _objectSpread2.default)({}, defaultProps, {
      isLoading: true,
      input: {}
    }), _react.default.createElement(MyComponent, null)));
    var MyComponentElement = wrapper.find('MyComponent');

    _assert.default.equal(MyComponentElement.length, 0);

    var LinearProgressElement = wrapper.find('LinearProgress');

    _assert.default.equal(LinearProgressElement.length, 1);
  });
  it('should display an error if error is defined', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceArrayInput.ReferenceArrayInputView, (0, _objectSpread2.default)({}, defaultProps, {
      error: 'ra.input.references.all_missing',
      input: {}
    }), _react.default.createElement(MyComponent, null)));
    var MyComponentElement = wrapper.find('MyComponent');

    _assert.default.equal(MyComponentElement.length, 0);

    var ErrorElement = wrapper.find('ReferenceError');

    _assert.default.equal(ErrorElement.length, 1);

    _assert.default.equal(ErrorElement.prop('error'), 'ra.input.references.all_missing');
  });
  it('should send an error to the children if warning is defined', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceArrayInput.ReferenceArrayInputView, (0, _objectSpread2.default)({}, defaultProps, {
      warning: 'fetch error',
      input: {
        value: [1, 2]
      },
      choices: [{
        id: 2
      }]
    }), _react.default.createElement(MyComponent, null)));
    var ErrorElement = wrapper.find('ReferenceError');

    _assert.default.equal(ErrorElement.length, 0);

    var MyComponentElement = wrapper.find('MyComponent');

    _assert.default.equal(MyComponentElement.length, 1);

    _assert.default.deepEqual(MyComponentElement.prop('meta'), {
      helperText: 'fetch error'
    });
  });
  it('should not send an error to the children if warning is not defined', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceArrayInput.ReferenceArrayInputView, (0, _objectSpread2.default)({}, defaultProps, {
      input: {
        value: [1, 2]
      },
      choices: [{
        id: 1
      }, {
        id: 2
      }]
    }), _react.default.createElement(MyComponent, null)));
    var ErrorElement = wrapper.find('ReferenceError');

    _assert.default.equal(ErrorElement.length, 0);

    var MyComponentElement = wrapper.find('MyComponent');

    _assert.default.equal(MyComponentElement.length, 1);

    _assert.default.deepEqual(MyComponentElement.prop('meta'), {
      helperText: false
    });
  });
  it('should render enclosed component if references present in input are available in state', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceArrayInput.ReferenceArrayInputView, (0, _objectSpread2.default)({}, defaultProps, {
      input: {
        value: [1]
      },
      choices: [1]
    }), _react.default.createElement(MyComponent, null)));
    var ErrorElement = wrapper.find('ReferenceError');

    _assert.default.equal(ErrorElement.length, 0);

    var MyComponentElement = wrapper.find('MyComponent');

    _assert.default.equal(MyComponentElement.length, 1);

    _assert.default.deepEqual(MyComponentElement.prop('choices'), [1]);
  });
  it('should render enclosed component even if the choices are empty', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceArrayInput.ReferenceArrayInputView, (0, _objectSpread2.default)({}, defaultProps, {
      choices: []
    }), _react.default.createElement(MyComponent, null)));
    var LinearProgressElement = wrapper.find('WithStyles(LinearProgress)');

    _assert.default.equal(LinearProgressElement.length, 0);

    var ErrorElement = wrapper.find('ReferenceError');

    _assert.default.equal(ErrorElement.length, 0);

    var MyComponentElement = wrapper.find('MyComponent');

    _assert.default.equal(MyComponentElement.length, 1);

    _assert.default.deepEqual(MyComponentElement.prop('choices'), []);
  });
  it('should pass onChange down to child component', function () {
    var onChange = jest.fn();
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceArrayInput.ReferenceArrayInputView, (0, _extends2.default)({}, defaultProps, {
      allowEmpty: true,
      onChange: onChange
    }), _react.default.createElement(MyComponent, null)));
    wrapper.find('MyComponent').simulate('change', 'foo');

    _assert.default.deepEqual(onChange.mock.calls[0], ['foo']);
  });
  it('should pass meta down to child component', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceArrayInput.ReferenceArrayInputView, (0, _extends2.default)({}, defaultProps, {
      allowEmpty: true,
      meta: {
        touched: false
      }
    }), _react.default.createElement(MyComponent, null)));
    var myComponent = wrapper.find('MyComponent');

    _assert.default.notEqual(myComponent.prop('meta', undefined));
  });
});