"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _react = _interopRequireDefault(require("react"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _ReferenceInput = require("../ReferenceInput");

describe('<ReferenceInput />', function () {
  var defaultProps = {
    meta: {},
    input: {},
    label: '',
    record: {},
    reference: 'posts',
    resource: 'comments',
    source: 'post_id',
    translate: function translate(x) {
      return "*".concat(x, "*");
    }
  };

  var MyComponent = function MyComponent() {
    return _react.default.createElement("span", {
      id: "mycomponent"
    });
  };

  it('should render a LinearProgress if isLoading is true', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceInput.ReferenceInputView, (0, _objectSpread2.default)({}, defaultProps, {
      input: {
        value: 1
      },
      isLoading: true
    }), _react.default.createElement(MyComponent, null)));
    var MyComponentElement = wrapper.find('MyComponent');

    _assert.default.equal(MyComponentElement.length, 0);

    var LinearProgressElement = wrapper.find('LinearProgress');

    _assert.default.equal(LinearProgressElement.length, 1);
  });
  it('should not render a LinearProgress if isLoading is false', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceInput.ReferenceInputView, (0, _objectSpread2.default)({}, defaultProps, {
      choices: [{
        id: 1
      }],
      input: {
        value: 1
      }
    }), _react.default.createElement(MyComponent, null)));
    var LinearProgressElement = wrapper.find('WithStyles(LinearProgress)');

    _assert.default.equal(LinearProgressElement.length, 0);

    var MyComponentElement = wrapper.find('MyComponent');

    _assert.default.equal(MyComponentElement.length, 1);

    _assert.default.deepEqual(MyComponentElement.prop('choices'), [{
      id: 1
    }]);
  });
  it('should display an error if error is defined', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceInput.ReferenceInputView, (0, _objectSpread2.default)({}, defaultProps, {
      error: 'fetch error',
      input: {
        value: 1
      }
    }), _react.default.createElement(MyComponent, null)));
    var MyComponentElement = wrapper.find('MyComponent');

    _assert.default.equal(MyComponentElement.length, 0);

    var ErrorElement = wrapper.find('ReferenceError');

    _assert.default.equal(ErrorElement.length, 1);

    _assert.default.equal(ErrorElement.prop('error'), 'fetch error');
  });
  it('should pass warning as helperText to the children if defined', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceInput.ReferenceInputView, (0, _objectSpread2.default)({}, defaultProps, {
      warning: 'fetch error',
      choices: [{
        id: 1
      }],
      input: {
        value: 1
      }
    }), _react.default.createElement(MyComponent, null)));
    var ReferenceLoadingProgressElement = wrapper.find('ReferenceLoadingProgress');

    _assert.default.equal(ReferenceLoadingProgressElement.length, 0);

    var ErrorElement = wrapper.find('ReferenceError');

    _assert.default.equal(ErrorElement.length, 0);

    var MyComponentElement = wrapper.find('MyComponent');

    _assert.default.equal(MyComponentElement.length, 1);

    _assert.default.deepEqual(MyComponentElement.prop('meta'), {
      helperText: 'fetch error'
    });

    _assert.default.deepEqual(MyComponentElement.prop('choices'), [{
      id: 1
    }]);
  });
  it('should pass onChange down to child component', function () {
    var onChange = jest.fn();
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceInput.ReferenceInputView, (0, _extends2.default)({}, defaultProps, {
      allowEmpty: true,
      onChange: onChange
    }), _react.default.createElement(MyComponent, null)));
    wrapper.find('MyComponent').simulate('change', 'foo');

    _assert.default.deepEqual(onChange.mock.calls[0], ['foo']);
  });
  it('should pass meta down to child component', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_ReferenceInput.ReferenceInputView, (0, _extends2.default)({}, defaultProps, {
      allowEmpty: true,
      meta: {
        touched: false
      }
    }), _react.default.createElement(MyComponent, null)));
    var myComponent = wrapper.find('MyComponent');

    _assert.default.notEqual(myComponent.prop('meta', undefined));
  });
});