"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _react = _interopRequireDefault(require("react"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _SelectArrayInput = require("../SelectArrayInput");

describe('<SelectArrayInput />', function () {
  var defaultProps = {
    classes: {},
    source: 'foo',
    meta: {},
    input: {},
    translate: function translate(x) {
      return x;
    }
  };
  it('should use a mui Select', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectArrayInput.SelectArrayInput, (0, _extends2.default)({}, defaultProps, {
      input: {
        value: ['programming']
      }
    })));
    var SelectFieldElement = wrapper.find('SelectMutiple__SelectInput');

    _assert.default.equal(SelectFieldElement.length, 1);
  });
  it('should use the input parameter value as the initial input value', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectArrayInput.SelectArrayInput, (0, _extends2.default)({}, defaultProps, {
      input: {
        value: ['programming', 'lifestyle']
      }
    })));
    var SelectFieldElement = wrapper.find('SelectMutiple__SelectInput');

    _assert.default.deepEqual(SelectFieldElement.prop('value'), ['programming', 'lifestyle']);
  });
  it('should render choices as mui MenuItem components', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectArrayInput.SelectArrayInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 'programming',
        name: 'Programming'
      }, {
        id: 'lifestyle',
        name: 'Lifestyle'
      }, {
        id: 'photography',
        name: 'Photography'
      }]
    })));
    var MenuItemElements = wrapper.find('Option');

    _assert.default.equal(MenuItemElements.length, 3);

    var MenuItemElement1 = MenuItemElements.first();

    _assert.default.equal(MenuItemElement1.prop('value'), 'programming');

    _assert.default.equal(MenuItemElement1.childAt(0).text(), 'Programming');

    var MenuItemElement2 = MenuItemElements.at(1);

    _assert.default.equal(MenuItemElement2.prop('value'), 'lifestyle');

    _assert.default.equal(MenuItemElement2.childAt(0).text(), 'Lifestyle');

    var MenuItemElement3 = MenuItemElements.at(2);

    _assert.default.equal(MenuItemElement3.prop('value'), 'photography');

    _assert.default.equal(MenuItemElement3.childAt(0).text(), 'Photography');
  });
  it('should use optionValue as value identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectArrayInput.SelectArrayInput, (0, _extends2.default)({}, defaultProps, {
      optionValue: "foobar",
      choices: [{
        foobar: 'M',
        name: 'Male'
      }]
    })));
    var MenuItemElements = wrapper.find('Option');
    var MenuItemElement1 = MenuItemElements.first();

    _assert.default.equal(MenuItemElement1.prop('value'), 'M');

    _assert.default.equal(MenuItemElement1.childAt(0).text(), 'Male');
  });
  it('should use optionValue including "." as value identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectArrayInput.SelectArrayInput, (0, _extends2.default)({}, defaultProps, {
      optionValue: "foobar.id",
      choices: [{
        foobar: {
          id: 'M'
        },
        name: 'Male'
      }]
    })));
    var MenuItemElements = wrapper.find('Option');
    var MenuItemElement1 = MenuItemElements.first();

    _assert.default.equal(MenuItemElement1.prop('value'), 'M');

    _assert.default.equal(MenuItemElement1.childAt(0).text(), 'Male');
  });
  it('should use optionText with a string value as text identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectArrayInput.SelectArrayInput, (0, _extends2.default)({}, defaultProps, {
      optionText: "foobar",
      choices: [{
        id: 'M',
        foobar: 'Male'
      }]
    })));
    var MenuItemElements = wrapper.find('Option');
    var MenuItemElement1 = MenuItemElements.first();

    _assert.default.equal(MenuItemElement1.prop('value'), 'M');

    _assert.default.equal(MenuItemElement1.childAt(0).text(), 'Male');
  });
  it('should use optionText with a string value including "." as text identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectArrayInput.SelectArrayInput, (0, _extends2.default)({}, defaultProps, {
      optionText: "foobar.name",
      choices: [{
        id: 'M',
        foobar: {
          name: 'Male'
        }
      }]
    })));
    var MenuItemElements = wrapper.find('Option');
    var MenuItemElement1 = MenuItemElements.first();

    _assert.default.equal(MenuItemElement1.prop('value'), 'M');

    _assert.default.equal(MenuItemElement1.childAt(0).text(), 'Male');
  });
  it('should use optionText with a function value as text identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectArrayInput.SelectArrayInput, (0, _extends2.default)({}, defaultProps, {
      optionText: function optionText(choice) {
        return choice.foobar;
      },
      choices: [{
        id: 'M',
        foobar: 'Male'
      }]
    })));
    var MenuItemElements = wrapper.find('Option');
    var MenuItemElement1 = MenuItemElements.first();

    _assert.default.equal(MenuItemElement1.prop('value'), 'M');

    _assert.default.equal(MenuItemElement1.childAt(0).text(), 'Male');
  });
  it('should use optionText with an element value as text identifier', function () {
    var Foobar = function Foobar(_ref) {
      var record = _ref.record;
      return _react.default.createElement("span", null, record.foobar);
    };

    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectArrayInput.SelectArrayInput, (0, _extends2.default)({}, defaultProps, {
      optionText: _react.default.createElement(Foobar, null),
      choices: [{
        id: 'M',
        foobar: 'Male'
      }]
    })));
    var MenuItemElements = wrapper.find('Option');
    var MenuItemElement1 = MenuItemElements.first();

    _assert.default.equal(MenuItemElement1.prop('value'), 'M');

    _assert.default.equal(MenuItemElement1.childAt(0).type(), Foobar);

    _assert.default.deepEqual(MenuItemElement1.childAt(0).prop('record'), {
      id: 'M',
      foobar: 'Male'
    });
  });
  it('should translate the choices', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectArrayInput.SelectArrayInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 'M',
        name: 'Male'
      }, {
        id: 'F',
        name: 'Female'
      }],
      translate: function translate(x) {
        return "**".concat(x, "**");
      }
    })));
    var MenuItemElements = wrapper.find('Option');
    var MenuItemElement1 = MenuItemElements.first();

    _assert.default.equal(MenuItemElement1.prop('value'), 'M');

    _assert.default.equal(MenuItemElement1.childAt(0).text(), '**Male**');
  });
  it('should displayed helperText if prop is present in meta', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectArrayInput.SelectArrayInput, (0, _extends2.default)({}, defaultProps, {
      meta: {
        helperText: 'Can i help you?'
      }
    })));
    var helperText = wrapper.find('FormFeedback');

    _assert.default.equal(helperText.length, 1);

    _assert.default.equal(helperText.childAt(0).text(), 'Can i help you?');
  });
  describe('error message', function () {
    it('should not be displayed if field is pristine', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectArrayInput.SelectArrayInput, (0, _extends2.default)({}, defaultProps, {
        meta: {
          touched: false
        }
      })));
      var helperText = wrapper.find('FormFeedback');

      _assert.default.equal(helperText.length, 0);
    });
    it('should not be displayed if field has been touched but is valid', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectArrayInput.SelectArrayInput, (0, _extends2.default)({}, defaultProps, {
        meta: {
          touched: true,
          error: false
        }
      })));
      var helperText = wrapper.find('FormFeedback');

      _assert.default.equal(helperText.length, 0);
    });
    it('should be displayed if field has been touched and is invalid', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectArrayInput.SelectArrayInput, (0, _extends2.default)({}, defaultProps, {
        meta: {
          touched: true,
          error: 'Required field.'
        }
      })));
      var helperText = wrapper.find('FormFeedback');

      _assert.default.equal(helperText.length, 1);

      _assert.default.equal(helperText.childAt(0).text(), 'Required field.');
    });
    it('should be displayed with an helper Text', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectArrayInput.SelectArrayInput, (0, _extends2.default)({}, defaultProps, {
        meta: {
          touched: true,
          error: 'Required field.',
          helperText: 'Can i help you?'
        }
      })));
      var helperText = wrapper.find('FormFeedback');

      _assert.default.equal(helperText.length, 2);

      _assert.default.equal(helperText.at(0).childAt(0).text(), 'Required field.');

      _assert.default.equal(helperText.at(1).childAt(0).text(), 'Can i help you?');
    });
  });
});