"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _react = _interopRequireDefault(require("react"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _SelectInput = require("../SelectInput");

describe('<SelectInput />', function () {
  var defaultProps = {
    source: 'foo',
    meta: {},
    input: {},
    translate: function translate(x) {
      return x;
    }
  };
  it('should use a ResettableTextField', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectInput.SelectInput, (0, _extends2.default)({}, defaultProps, {
      input: {
        value: 'hello'
      }
    })));
    var SelectFieldElement = wrapper.find('translate(ResettableTextField)');

    _assert.default.equal(SelectFieldElement.length, 1);

    _assert.default.equal(SelectFieldElement.prop('value'), 'hello');
  });
  it('should use the input parameter value as the initial input value', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectInput.SelectInput, (0, _extends2.default)({}, defaultProps, {
      input: {
        value: 2
      }
    })));
    var SelectFieldElement = wrapper.find('translate(ResettableTextField)').first();

    _assert.default.equal(SelectFieldElement.prop('value'), '2');
  });
  it('should render choices as mui MenuItem components', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectInput.SelectInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 'M',
        name: 'Male'
      }, {
        id: 'F',
        name: 'Female'
      }]
    })));
    var MenuItemElements = wrapper.find('Option');

    _assert.default.equal(MenuItemElements.length, 2);

    var MenuItemElement1 = MenuItemElements.first();

    _assert.default.equal(MenuItemElement1.prop('value'), 'M');

    _assert.default.equal(MenuItemElement1.childAt(0).text(), 'Male');

    var MenuItemElement2 = MenuItemElements.at(1);

    _assert.default.equal(MenuItemElement2.prop('value'), 'F');

    _assert.default.equal(MenuItemElement2.childAt(0).text(), 'Female');
  });
  it('should render disable choices marked so', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectInput.SelectInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 123,
        full_name: 'Leo Tolstoi',
        sex: 'M'
      }, {
        id: 456,
        full_name: 'Jane Austen',
        sex: 'F'
      }, {
        id: 1,
        full_name: 'System Administrator',
        sex: 'F',
        disabled: true
      }]
    })));
    var MenuItemElements = wrapper.find('Option');
    var MenuItemElement = MenuItemElements.at(1);

    _assert.default.equal(!!MenuItemElement.prop('disabled'), false);

    var MenuItemElement2 = MenuItemElements.at(2);

    _assert.default.equal(MenuItemElement2.prop('disabled'), true);
  });
  it('should add an empty menu when allowEmpty is true', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectInput.SelectInput, (0, _extends2.default)({
      allowEmpty: true
    }, defaultProps, {
      choices: [{
        id: 'M',
        name: 'Male'
      }, {
        id: 'F',
        name: 'Female'
      }]
    })));
    var MenuItemElements = wrapper.find('Option');

    _assert.default.equal(MenuItemElements.length, 3);

    var MenuItemElement1 = MenuItemElements.first();

    _assert.default.equal(MenuItemElement1.prop('value'), '');

    _assert.default.equal(MenuItemElement1.children().length, 0);
  });
  it('should not add a falsy (null or false) element when allowEmpty is false', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectInput.SelectInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 'M',
        name: 'Male'
      }, {
        id: 'F',
        name: 'Female'
      }]
    })));
    var MenuItemElements = wrapper.find('Option');

    _assert.default.equal(MenuItemElements.length, 2);
  });
  it('should use optionValue as value identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectInput.SelectInput, (0, _extends2.default)({}, defaultProps, {
      optionValue: "foobar",
      choices: [{
        foobar: 'M',
        name: 'Male'
      }]
    })));
    var MenuItemElements = wrapper.find('Option');
    var MenuItemElement1 = MenuItemElements.first();

    _assert.default.equal(MenuItemElement1.prop('value'), 'M');

    _assert.default.equal(MenuItemElement1.childAt(0).text(), 'Male');
  });
  it('should use optionValue including "." as value identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectInput.SelectInput, (0, _extends2.default)({}, defaultProps, {
      optionValue: "foobar.id",
      choices: [{
        foobar: {
          id: 'M'
        },
        name: 'Male'
      }]
    })));
    var MenuItemElements = wrapper.find('Option');
    var MenuItemElement1 = MenuItemElements.first();

    _assert.default.equal(MenuItemElement1.prop('value'), 'M');

    _assert.default.equal(MenuItemElement1.childAt(0).text(), 'Male');
  });
  it('should use optionText with a string value as text identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectInput.SelectInput, (0, _extends2.default)({}, defaultProps, {
      optionText: "foobar",
      choices: [{
        id: 'M',
        foobar: 'Male'
      }]
    })));
    var MenuItemElements = wrapper.find('Option');
    var MenuItemElement1 = MenuItemElements.first();

    _assert.default.equal(MenuItemElement1.prop('value'), 'M');

    _assert.default.equal(MenuItemElement1.childAt(0).text(), 'Male');
  });
  it('should use optionText with a string value including "." as text identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectInput.SelectInput, (0, _extends2.default)({}, defaultProps, {
      optionText: "foobar.name",
      choices: [{
        id: 'M',
        foobar: {
          name: 'Male'
        }
      }]
    })));
    var MenuItemElements = wrapper.find('Option');
    var MenuItemElement1 = MenuItemElements.first();

    _assert.default.equal(MenuItemElement1.prop('value'), 'M');

    _assert.default.equal(MenuItemElement1.childAt(0).text(), 'Male');
  });
  it('should use optionText with a function value as text identifier', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectInput.SelectInput, (0, _extends2.default)({}, defaultProps, {
      optionText: function optionText(choice) {
        return choice.foobar;
      },
      choices: [{
        id: 'M',
        foobar: 'Male'
      }]
    })));
    var MenuItemElements = wrapper.find('Option');
    var MenuItemElement1 = MenuItemElements.first();

    _assert.default.equal(MenuItemElement1.prop('value'), 'M');

    _assert.default.equal(MenuItemElement1.childAt(0).text(), 'Male');
  });
  it('should use optionText with an element value as text identifier', function () {
    var Foobar = function Foobar(_ref) {
      var record = _ref.record;
      return _react.default.createElement("span", null, record.foobar);
    };

    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectInput.SelectInput, (0, _extends2.default)({}, defaultProps, {
      optionText: _react.default.createElement(Foobar, null),
      choices: [{
        id: 'M',
        foobar: 'Male'
      }]
    })));
    var MenuItemElements = wrapper.find('Option');
    var MenuItemElement1 = MenuItemElements.first();

    _assert.default.equal(MenuItemElement1.prop('value'), 'M');

    _assert.default.equal(MenuItemElement1.childAt(0).type(), Foobar);

    _assert.default.deepEqual(MenuItemElement1.childAt(0).prop('record'), {
      id: 'M',
      foobar: 'Male'
    });
  });
  it('should translate the choices by default', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectInput.SelectInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 'M',
        name: 'Male'
      }, {
        id: 'F',
        name: 'Female'
      }],
      translate: function translate(x) {
        return "**".concat(x, "**");
      }
    })));
    var MenuItemElements = wrapper.find('Option');
    var MenuItemElement1 = MenuItemElements.first();

    _assert.default.equal(MenuItemElement1.prop('value'), 'M');

    _assert.default.equal(MenuItemElement1.childAt(0).text(), '**Male**');
  });
  it('should not translate the choices if translateChoice is false', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectInput.SelectInput, (0, _extends2.default)({}, defaultProps, {
      choices: [{
        id: 'M',
        name: 'Male'
      }, {
        id: 'F',
        name: 'Female'
      }],
      translate: function translate(x) {
        return "**".concat(x, "**");
      },
      translateChoice: false
    })));
    var MenuItemElements = wrapper.find('Option');
    var MenuItemElement1 = MenuItemElements.first();

    _assert.default.equal(MenuItemElement1.prop('value'), 'M');

    _assert.default.equal(MenuItemElement1.childAt(0).text(), 'Male');
  });
  it('should displayed helperText if prop is present in meta', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectInput.SelectInput, (0, _extends2.default)({}, defaultProps, {
      meta: {
        helperText: 'Can i help you?'
      }
    })));
    var SelectFieldElement = wrapper.find('translate(ResettableTextField)');

    _assert.default.equal(SelectFieldElement.prop('helperText'), 'Can i help you?');
  });
  describe('error message', function () {
    it('should not be displayed if field is pristine', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectInput.SelectInput, (0, _extends2.default)({}, defaultProps, {
        meta: {
          touched: false
        }
      })));
      var SelectFieldElement = wrapper.find('translate(ResettableTextField)');

      _assert.default.equal(SelectFieldElement.prop('helperText'), false);
    });
    it('should not be displayed if field has been touched but is valid', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectInput.SelectInput, (0, _extends2.default)({}, defaultProps, {
        meta: {
          touched: true,
          error: false
        }
      })));
      var SelectFieldElement = wrapper.find('translate(ResettableTextField)');

      _assert.default.equal(SelectFieldElement.prop('helperText'), false);
    });
    it('should be displayed if field has been touched and is invalid', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectInput.SelectInput, (0, _extends2.default)({}, defaultProps, {
        meta: {
          touched: true,
          error: 'Required field.'
        }
      })));
      var SelectFieldElement = wrapper.find('translate(ResettableTextField)');

      _assert.default.equal(SelectFieldElement.prop('helperText'), 'Required field.');
    });
    it('should display the error even if helperText is present', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SelectInput.SelectInput, (0, _extends2.default)({}, defaultProps, {
        meta: {
          touched: true,
          error: 'Required field.',
          helperText: 'Can i help you?'
        }
      })));
      var SelectFieldElement = wrapper.find('translate(ResettableTextField)');

      _assert.default.equal(SelectFieldElement.prop('helperText'), 'Required field.');
    });
  });
});