"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _enzyme = require("enzyme");

var _assert = _interopRequireDefault(require("assert"));

var _react = _interopRequireDefault(require("react"));

var _TextInput = require("../TextInput");

describe('<TextInput />', function () {
  var defaultProps = {
    source: 'foo',
    meta: {},
    input: {}
  };
  it('should use a ResettableTextField when type is text', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_TextInput.TextInput, (0, _extends2.default)({}, defaultProps, {
      input: {
        value: 'hello'
      }
    })));
    var TextFieldElement = wrapper.find('translate(ResettableTextField)');

    _assert.default.equal(TextFieldElement.length, 1);

    _assert.default.equal(TextFieldElement.prop('value'), 'hello');

    _assert.default.equal(TextFieldElement.prop('type'), 'text');
  });
  it('should use a ResettableTextField when type is password', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_TextInput.TextInput, (0, _extends2.default)({}, defaultProps, {
      type: "password"
    })));
    var TextFieldElement = wrapper.find('translate(ResettableTextField)');

    _assert.default.equal(TextFieldElement.length, 1);

    _assert.default.equal(TextFieldElement.prop('type'), 'password');
  });
  it('should call redux-form onBlur handler when blurred', function () {
    var onBlur = jest.fn();
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_TextInput.TextInput, (0, _extends2.default)({}, defaultProps, {
      input: {
        onBlur: onBlur
      }
    })));
    var TextFieldElement = wrapper.find('translate(ResettableTextField)').first();
    TextFieldElement.simulate('blur', 'event');

    _assert.default.equal(onBlur.mock.calls[0][0], 'event');
  });
  describe('error message', function () {
    it('should not be displayed if field is pristine', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_TextInput.TextInput, (0, _extends2.default)({}, defaultProps, {
        meta: {
          touched: false
        }
      })));
      var TextFieldElement = wrapper.find('translate(ResettableTextField)');

      _assert.default.equal(TextFieldElement.prop('helperText'), false);
    });
    it('should not be displayed if field has been touched but is valid', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_TextInput.TextInput, (0, _extends2.default)({}, defaultProps, {
        meta: {
          touched: true,
          error: false
        }
      })));
      var TextFieldElement = wrapper.find('translate(ResettableTextField)');

      _assert.default.equal(TextFieldElement.prop('helperText'), false);
    });
    it('should be displayed if field has been touched and is invalid', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_TextInput.TextInput, (0, _extends2.default)({}, defaultProps, {
        meta: {
          touched: true,
          error: 'Required field.'
        }
      })));
      var TextFieldElement = wrapper.find('translate(ResettableTextField)');

      _assert.default.equal(TextFieldElement.prop('helperText'), 'Required field.');
    });
  });
});