"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _assert = _interopRequireDefault(require("assert"));

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _DatagridHeaderCell = require("../DatagridHeaderCell");

describe('<DatagridHeaderCell />', function () {
  describe('sorting on a column', function () {
    var Field = function Field() {
      return _react.default.createElement("div", null);
    };

    Field.defaultProps = {
      type: 'foo',
      updateSort: function updateSort() {
        return true;
      }
    };
    it('should be enabled when field has a source', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_DatagridHeaderCell.DatagridHeaderCell, {
        currentSort: {},
        field: _react.default.createElement(Field, {
          source: "title"
        }),
        updateSort: function updateSort() {
          return true;
        },
        translate: function translate() {
          return '';
        }
      }));

      _assert.default.equal(wrapper.find('DatagridHeaderCell__ThContainer').length, 1);
    });
    it('should be enabled when field has a sortBy props', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_DatagridHeaderCell.DatagridHeaderCell, {
        currentSort: {},
        field: _react.default.createElement(Field, {
          sortBy: "title"
        }),
        updateSort: function updateSort() {
          return true;
        },
        translate: function translate() {
          return '';
        }
      }));

      _assert.default.equal(wrapper.find('DatagridHeaderCell__ThContainer').length, 1);
    });
    it('should be disabled when field has no sortby and no source', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_DatagridHeaderCell.DatagridHeaderCell, {
        currentSort: {},
        field: _react.default.createElement(Field, null),
        updateSort: function updateSort() {
          return true;
        },
        translate: function translate() {
          return '';
        }
      }));

      _assert.default.equal(wrapper.find('DatagridHeaderCell__ThContainer').length, 0);
    });
    it('should be disabled when sortable prop is explicitly set to false', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_DatagridHeaderCell.DatagridHeaderCell, {
        currentSort: {},
        field: _react.default.createElement(Field, {
          source: "title",
          sortable: false
        }),
        updateSort: function updateSort() {
          return true;
        },
        translate: function translate() {
          return '';
        }
      }));

      _assert.default.equal(wrapper.find('DatagridHeaderCell__ThContainer').length, 0);
    });
    it('should use cell className if specified', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_DatagridHeaderCell.DatagridHeaderCell, {
        currentSort: {},
        updateSort: function updateSort() {
          return true;
        },
        translate: function translate() {
          return '';
        },
        field: _react.default.createElement(Field, null),
        className: "blue"
      }));
      var col = wrapper.find('Th');

      _assert.default.deepEqual(col.at(0).prop('className'), 'blue');
    });
  });
});