"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _assert = _interopRequireDefault(require("assert"));

var _enzyme = require("enzyme");

var _SingleFieldList = require("../SingleFieldList");

var _ChipField = _interopRequireDefault(require("../../field/ChipField"));

describe('<SingleFieldList />', function () {
  it('should render a link to the Edit page of the related record by default', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SingleFieldList.SingleFieldList, {
      ids: [1, 2],
      data: {
        1: {
          id: 1,
          title: 'foo'
        },
        2: {
          id: 2,
          title: 'bar'
        }
      },
      resource: "posts",
      basePath: "/posts"
    }, _react.default.createElement(_ChipField.default, {
      source: "title"
    })));
    var linkElements = wrapper.find('Link');

    _assert.default.equal(linkElements.length, 2);

    _assert.default.deepEqual(linkElements.map(function (link) {
      return link.prop('to');
    }), ['/posts/1', '/posts/2']);
  });
  it('should render a link to the Edit page of the related record when the resource contains slashes', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SingleFieldList.SingleFieldList, {
      ids: [1, 2],
      data: {
        1: {
          id: 1,
          title: 'foo'
        },
        2: {
          id: 2,
          title: 'bar'
        }
      },
      resource: "posts",
      basePath: "/posts"
    }, _react.default.createElement(_ChipField.default, {
      source: "title"
    })));
    var linkElements = wrapper.find('Link');

    _assert.default.equal(linkElements.length, 2);

    _assert.default.deepEqual(linkElements.map(function (link) {
      return link.prop('to');
    }), ['/posts/1', '/posts/2']);
  });
  it('should render a link to the Edit page of the related record when the resource is named edit or show', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SingleFieldList.SingleFieldList, {
      ids: [1, 2],
      data: {
        1: {
          id: 1,
          title: 'foo'
        },
        2: {
          id: 2,
          title: 'bar'
        }
      },
      resource: "edit",
      basePath: "/edit"
    }, _react.default.createElement(_ChipField.default, {
      source: "title"
    })));
    var linkElements = wrapper.find('Link');

    _assert.default.equal(linkElements.length, 2);

    _assert.default.deepEqual(linkElements.map(function (link) {
      return link.prop('to');
    }), ['/edit/1', '/edit/2']);

    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SingleFieldList.SingleFieldList, {
      ids: [1, 2],
      data: {
        1: {
          id: 1,
          title: 'foo'
        },
        2: {
          id: 2,
          title: 'bar'
        }
      },
      resource: "show",
      basePath: "/show"
    }, _react.default.createElement(_ChipField.default, {
      source: "title"
    })));
    linkElements = wrapper.find('Link');

    _assert.default.equal(linkElements.length, 2);

    _assert.default.deepEqual(linkElements.map(function (link) {
      return link.prop('to');
    }), ['/show/1', '/show/2']);
  });
  it('should render a link to the Show page of the related record when the linkType is show', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SingleFieldList.SingleFieldList, {
      ids: [1, 2],
      data: {
        1: {
          id: 1,
          title: 'foo'
        },
        2: {
          id: 2,
          title: 'bar'
        }
      },
      resource: "prefix/bar",
      basePath: "/prefix/bar",
      linkType: "show"
    }, _react.default.createElement(_ChipField.default, {
      source: "title"
    })));
    var linkElements = wrapper.find('Link');

    _assert.default.equal(linkElements.length, 2);

    _assert.default.deepEqual(linkElements.map(function (link) {
      return link.prop('to');
    }), ['/prefix/bar/1/show', '/prefix/bar/2/show']);
  });
  it('should render a link to the Edit page of the related record when the resource is named edit or show and linkType is show', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SingleFieldList.SingleFieldList, {
      ids: [1, 2],
      data: {
        1: {
          id: 1,
          title: 'foo'
        },
        2: {
          id: 2,
          title: 'bar'
        }
      },
      resource: "edit",
      basePath: "/edit",
      linkType: "show"
    }, _react.default.createElement(_ChipField.default, {
      source: "title"
    })));
    var linkElements = wrapper.find('Link');

    _assert.default.equal(linkElements.length, 2);

    _assert.default.deepEqual(linkElements.map(function (link) {
      return link.prop('to');
    }), ['/edit/1/show', '/edit/2/show']);

    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SingleFieldList.SingleFieldList, {
      ids: [1, 2],
      data: {
        1: {
          id: 1,
          title: 'foo'
        },
        2: {
          id: 2,
          title: 'bar'
        }
      },
      resource: "show",
      basePath: "/show",
      linkType: "show"
    }, _react.default.createElement(_ChipField.default, {
      source: "title"
    })));
    linkElements = wrapper.find('Link');

    _assert.default.equal(linkElements.length, 2);

    _assert.default.deepEqual(linkElements.map(function (link) {
      return link.prop('to');
    }), ['/show/1/show', '/show/2/show']);
  });
  it('should render no link when the linkType is false', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SingleFieldList.SingleFieldList, {
      ids: [1, 2],
      data: {
        1: {
          id: 1,
          title: 'foo'
        },
        2: {
          id: 2,
          title: 'bar'
        }
      },
      resource: "bar",
      basePath: "/bar",
      linkType: false
    }, _react.default.createElement(_ChipField.default, {
      source: "title"
    })));
    var linkElements = wrapper.find('Link');

    _assert.default.equal(linkElements.length, 0);

    var chipElements = wrapper.find('pure(ChipField)');

    _assert.default.equal(chipElements.length, 2);
  });
});